pub struct CreateQueueFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateQueue.
Create a new transcoding queue. For information about queues, see Working With Queues in the User Guide at https://docs.aws.amazon.com/mediaconvert/latest/ug/working-with-queues.html
Implementations
Sourceimpl CreateQueueFluentBuilder
impl CreateQueueFluentBuilder
Sourcepub fn as_input(&self) -> &CreateQueueInputBuilder
pub fn as_input(&self) -> &CreateQueueInputBuilder
Access the CreateQueue as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateQueueOutput, SdkError<CreateQueueError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateQueueOutput, SdkError<CreateQueueError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateQueueOutput, CreateQueueError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateQueueOutput, CreateQueueError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn concurrent_jobs(self, input: i32) -> Self
pub fn concurrent_jobs(self, input: i32) -> Self
Specify the maximum number of jobs your queue can process concurrently. For on-demand queues, the value you enter is constrained by your service quotas for Maximum concurrent jobs, per on-demand queue and Maximum concurrent jobs, per account. For reserved queues, specify the number of jobs you can process concurrently in your reservation plan instead.
Sourcepub fn set_concurrent_jobs(self, input: Option<i32>) -> Self
pub fn set_concurrent_jobs(self, input: Option<i32>) -> Self
Specify the maximum number of jobs your queue can process concurrently. For on-demand queues, the value you enter is constrained by your service quotas for Maximum concurrent jobs, per on-demand queue and Maximum concurrent jobs, per account. For reserved queues, specify the number of jobs you can process concurrently in your reservation plan instead.
Sourcepub fn get_concurrent_jobs(&self) -> &Option<i32>
pub fn get_concurrent_jobs(&self) -> &Option<i32>
Specify the maximum number of jobs your queue can process concurrently. For on-demand queues, the value you enter is constrained by your service quotas for Maximum concurrent jobs, per on-demand queue and Maximum concurrent jobs, per account. For reserved queues, specify the number of jobs you can process concurrently in your reservation plan instead.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
Optional. A description of the queue that you are creating.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
Optional. A description of the queue that you are creating.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
Optional. A description of the queue that you are creating.
Sourcepub fn maximum_concurrent_feeds(self, input: i32) -> Self
pub fn maximum_concurrent_feeds(self, input: i32) -> Self
Specify the maximum number of Elemental Inference feeds MediaConvert can process concurrently.
Sourcepub fn set_maximum_concurrent_feeds(self, input: Option<i32>) -> Self
pub fn set_maximum_concurrent_feeds(self, input: Option<i32>) -> Self
Specify the maximum number of Elemental Inference feeds MediaConvert can process concurrently.
Sourcepub fn get_maximum_concurrent_feeds(&self) -> &Option<i32>
pub fn get_maximum_concurrent_feeds(&self) -> &Option<i32>
Specify the maximum number of Elemental Inference feeds MediaConvert can process concurrently.
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the queue that you are creating.
Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
The name of the queue that you are creating.
Sourcepub fn pricing_plan(self, input: PricingPlan) -> Self
pub fn pricing_plan(self, input: PricingPlan) -> Self
Specifies whether the pricing plan for the queue is on-demand or reserved. For on-demand, you pay per minute, billed in increments of .01 minute. For reserved, you pay for the transcoding capacity of the entire queue, regardless of how much or how little you use it. Reserved pricing requires a 12-month commitment. When you use the API to create a queue, the default is on-demand.
Sourcepub fn set_pricing_plan(self, input: Option<PricingPlan>) -> Self
pub fn set_pricing_plan(self, input: Option<PricingPlan>) -> Self
Specifies whether the pricing plan for the queue is on-demand or reserved. For on-demand, you pay per minute, billed in increments of .01 minute. For reserved, you pay for the transcoding capacity of the entire queue, regardless of how much or how little you use it. Reserved pricing requires a 12-month commitment. When you use the API to create a queue, the default is on-demand.
Sourcepub fn get_pricing_plan(&self) -> &Option<PricingPlan>
pub fn get_pricing_plan(&self) -> &Option<PricingPlan>
Specifies whether the pricing plan for the queue is on-demand or reserved. For on-demand, you pay per minute, billed in increments of .01 minute. For reserved, you pay for the transcoding capacity of the entire queue, regardless of how much or how little you use it. Reserved pricing requires a 12-month commitment. When you use the API to create a queue, the default is on-demand.
Sourcepub fn reservation_plan_settings(self, input: ReservationPlanSettings) -> Self
pub fn reservation_plan_settings(self, input: ReservationPlanSettings) -> Self
Details about the pricing plan for your reserved queue. Required for reserved queues and not applicable to on-demand queues.
Sourcepub fn set_reservation_plan_settings(
self,
input: Option<ReservationPlanSettings>,
) -> Self
pub fn set_reservation_plan_settings( self, input: Option<ReservationPlanSettings>, ) -> Self
Details about the pricing plan for your reserved queue. Required for reserved queues and not applicable to on-demand queues.
Sourcepub fn get_reservation_plan_settings(&self) -> &Option<ReservationPlanSettings>
pub fn get_reservation_plan_settings(&self) -> &Option<ReservationPlanSettings>
Details about the pricing plan for your reserved queue. Required for reserved queues and not applicable to on-demand queues.
Sourcepub fn status(self, input: QueueStatus) -> Self
pub fn status(self, input: QueueStatus) -> Self
Initial state of the queue. If you create a paused queue, then jobs in that queue won’t begin.
Sourcepub fn set_status(self, input: Option<QueueStatus>) -> Self
pub fn set_status(self, input: Option<QueueStatus>) -> Self
Initial state of the queue. If you create a paused queue, then jobs in that queue won’t begin.
Sourcepub fn get_status(&self) -> &Option<QueueStatus>
pub fn get_status(&self) -> &Option<QueueStatus>
Initial state of the queue. If you create a paused queue, then jobs in that queue won’t begin.
Adds a key-value pair to Tags.
To override the contents of this collection use set_tags.
The tags that you want to add to the resource. You can tag resources with a key-value pair or with only a key.
The tags that you want to add to the resource. You can tag resources with a key-value pair or with only a key.
The tags that you want to add to the resource. You can tag resources with a key-value pair or with only a key.