CreateQueueInputBuilder

Struct CreateQueueInputBuilder 

#[non_exhaustive]
pub struct CreateQueueInputBuilder { /* private fields */ }
A builder for CreateQueueInput.

Implementations

Source

impl CreateQueueInputBuilder

pub fn concurrent_jobs(self, input: i32) -> Self

Specify the maximum number of jobs your queue can process concurrently. For on-demand queues, the value you enter is constrained by your service quotas for Maximum concurrent jobs, per on-demand queue and Maximum concurrent jobs, per account. For reserved queues, specify the number of jobs you can process concurrently in your reservation plan instead.

pub fn set_concurrent_jobs(self, input: Option<i32>) -> Self

Specify the maximum number of jobs your queue can process concurrently. For on-demand queues, the value you enter is constrained by your service quotas for Maximum concurrent jobs, per on-demand queue and Maximum concurrent jobs, per account. For reserved queues, specify the number of jobs you can process concurrently in your reservation plan instead.

pub fn get_concurrent_jobs(&self) -> &Option<i32>

Specify the maximum number of jobs your queue can process concurrently. For on-demand queues, the value you enter is constrained by your service quotas for Maximum concurrent jobs, per on-demand queue and Maximum concurrent jobs, per account. For reserved queues, specify the number of jobs you can process concurrently in your reservation plan instead.

pub fn description(self, input: impl Into<String>) -> Self

Optional. A description of the queue that you are creating.

pub fn set_description(self, input: Option<String>) -> Self

Optional. A description of the queue that you are creating.

pub fn get_description(&self) -> &Option<String>

Optional. A description of the queue that you are creating.

pub fn maximum_concurrent_feeds(self, input: i32) -> Self

Specify the maximum number of Elemental Inference feeds MediaConvert can process concurrently.

pub fn set_maximum_concurrent_feeds(self, input: Option<i32>) -> Self

Specify the maximum number of Elemental Inference feeds MediaConvert can process concurrently.

pub fn get_maximum_concurrent_feeds(&self) -> &Option<i32>

Specify the maximum number of Elemental Inference feeds MediaConvert can process concurrently.

pub fn name(self, input: impl Into<String>) -> Self

The name of the queue that you are creating. This field is required.

pub fn set_name(self, input: Option<String>) -> Self

The name of the queue that you are creating.

pub fn get_name(&self) -> &Option<String>

The name of the queue that you are creating.

pub fn pricing_plan(self, input: PricingPlan) -> Self

Specifies whether the pricing plan for the queue is on-demand or reserved. For on-demand, you pay per minute, billed in increments of .01 minute. For reserved, you pay for the transcoding capacity of the entire queue, regardless of how much or how little you use it. Reserved pricing requires a 12-month commitment. When you use the API to create a queue, the default is on-demand.

pub fn set_pricing_plan(self, input: Option<PricingPlan>) -> Self

Specifies whether the pricing plan for the queue is on-demand or reserved. For on-demand, you pay per minute, billed in increments of .01 minute. For reserved, you pay for the transcoding capacity of the entire queue, regardless of how much or how little you use it. Reserved pricing requires a 12-month commitment. When you use the API to create a queue, the default is on-demand.

pub fn get_pricing_plan(&self) -> &Option<PricingPlan>

Specifies whether the pricing plan for the queue is on-demand or reserved. For on-demand, you pay per minute, billed in increments of .01 minute. For reserved, you pay for the transcoding capacity of the entire queue, regardless of how much or how little you use it. Reserved pricing requires a 12-month commitment. When you use the API to create a queue, the default is on-demand.

pub fn reservation_plan_settings(self, input: ReservationPlanSettings) -> Self

Details about the pricing plan for your reserved queue. Required for reserved queues and not applicable to on-demand queues.

pub fn set_reservation_plan_settings( self, input: Option<ReservationPlanSettings>, ) -> Self

Details about the pricing plan for your reserved queue. Required for reserved queues and not applicable to on-demand queues.

pub fn get_reservation_plan_settings(&self) -> &Option<ReservationPlanSettings>

Details about the pricing plan for your reserved queue. Required for reserved queues and not applicable to on-demand queues.

pub fn status(self, input: QueueStatus) -> Self

Initial state of the queue. If you create a paused queue, then jobs in that queue won’t begin.

pub fn set_status(self, input: Option<QueueStatus>) -> Self

Initial state of the queue. If you create a paused queue, then jobs in that queue won’t begin.

pub fn get_status(&self) -> &Option<QueueStatus>

Initial state of the queue. If you create a paused queue, then jobs in that queue won’t begin.

pub fn tags(self, k: impl Into<String>, v: impl Into<String>) -> Self

Adds a key-value pair to tags.

To override the contents of this collection use set_tags.

The tags that you want to add to the resource. You can tag resources with a key-value pair or with only a key.

pub fn set_tags(self, input: Option<HashMap<String, String>>) -> Self

The tags that you want to add to the resource. You can tag resources with a key-value pair or with only a key.

pub fn get_tags(&self) -> &Option<HashMap<String, String>>

The tags that you want to add to the resource. You can tag resources with a key-value pair or with only a key.

pub fn build(self) -> Result<CreateQueueInput, BuildError>

Consumes the builder and constructs a CreateQueueInput.

Source

impl CreateQueueInputBuilder

pub async fn send_with( self, client: &Client, ) -> Result<CreateQueueOutput, SdkError<CreateQueueError, HttpResponse>>

Sends a request with this input using the given client.