CreateQueueInput

Struct CreateQueueInput 

#[non_exhaustive]
pub struct CreateQueueInput { pub concurrent_jobs: Option<i32>, pub description: Option<String>, pub maximum_concurrent_feeds: Option<i32>, pub name: Option<String>, pub pricing_plan: Option<PricingPlan>, pub reservation_plan_settings: Option<ReservationPlanSettings>, pub status: Option<QueueStatus>, pub tags: Option<HashMap<String, String>>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
concurrent_jobs: Option<i32>

Specify the maximum number of jobs your queue can process concurrently. For on-demand queues, the value you enter is constrained by your service quotas for Maximum concurrent jobs, per on-demand queue and Maximum concurrent jobs, per account. For reserved queues, specify the number of jobs you can process concurrently in your reservation plan instead.

description: Option<String>

Optional. A description of the queue that you are creating.

maximum_concurrent_feeds: Option<i32>

Specify the maximum number of Elemental Inference feeds MediaConvert can process concurrently.

name: Option<String>

The name of the queue that you are creating.

pricing_plan: Option<PricingPlan>

Specifies whether the pricing plan for the queue is on-demand or reserved. For on-demand, you pay per minute, billed in increments of .01 minute. For reserved, you pay for the transcoding capacity of the entire queue, regardless of how much or how little you use it. Reserved pricing requires a 12-month commitment. When you use the API to create a queue, the default is on-demand.

reservation_plan_settings: Option<ReservationPlanSettings>

Details about the pricing plan for your reserved queue. Required for reserved queues and not applicable to on-demand queues.

status: Option<QueueStatus>

Initial state of the queue. If you create a paused queue, then jobs in that queue won’t begin.

tags: Option<HashMap<String, String>>

The tags that you want to add to the resource. You can tag resources with a key-value pair or with only a key.

Implementations

Source

impl CreateQueueInput

pub fn concurrent_jobs(&self) -> Option<i32>

Specify the maximum number of jobs your queue can process concurrently. For on-demand queues, the value you enter is constrained by your service quotas for Maximum concurrent jobs, per on-demand queue and Maximum concurrent jobs, per account. For reserved queues, specify the number of jobs you can process concurrently in your reservation plan instead.

pub fn description(&self) -> Option<&str>

Optional. A description of the queue that you are creating.

pub fn maximum_concurrent_feeds(&self) -> Option<i32>

Specify the maximum number of Elemental Inference feeds MediaConvert can process concurrently.

pub fn name(&self) -> Option<&str>

The name of the queue that you are creating.

pub fn pricing_plan(&self) -> Option<&PricingPlan>

Specifies whether the pricing plan for the queue is on-demand or reserved. For on-demand, you pay per minute, billed in increments of .01 minute. For reserved, you pay for the transcoding capacity of the entire queue, regardless of how much or how little you use it. Reserved pricing requires a 12-month commitment. When you use the API to create a queue, the default is on-demand.

pub fn reservation_plan_settings(&self) -> Option<&ReservationPlanSettings>

Details about the pricing plan for your reserved queue. Required for reserved queues and not applicable to on-demand queues.

pub fn status(&self) -> Option<&QueueStatus>

Initial state of the queue. If you create a paused queue, then jobs in that queue won’t begin.

pub fn tags(&self) -> Option<&HashMap<String, String>>

The tags that you want to add to the resource. You can tag resources with a key-value pair or with only a key.

Source

impl CreateQueueInput

pub fn builder() -> CreateQueueInputBuilder

Creates a new builder-style object to manufacture CreateQueueInput.