#[non_exhaustive]pub struct UpdateQueueInput {
pub concurrent_jobs: Option<i32>,
pub description: Option<String>,
pub maximum_concurrent_feeds: Option<i32>,
pub name: Option<String>,
pub reservation_plan_settings: Option<ReservationPlanSettings>,
pub status: Option<QueueStatus>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.concurrent_jobs: Option<i32>Specify the maximum number of jobs your queue can process concurrently. For on-demand queues, the value you enter is constrained by your service quotas for Maximum concurrent jobs, per on-demand queue and Maximum concurrent jobs, per account. For reserved queues, update your reservation plan instead in order to increase your yearly commitment.
description: Option<String>The new description for the queue, if you are changing it.
maximum_concurrent_feeds: Option<i32>Specify the maximum number of Elemental Inference feeds MediaConvert can process concurrently.
name: Option<String>The name of the queue that you are modifying.
reservation_plan_settings: Option<ReservationPlanSettings>The new details of your pricing plan for your reserved queue. When you set up a new pricing plan to replace an expired one, you enter into another 12-month commitment. When you add capacity to your queue by increasing the number of RTS, you extend the term of your commitment to 12 months from when you add capacity. After you make these commitments, you can’t cancel them.
status: Option<QueueStatus>Pause or activate a queue by changing its status between ACTIVE and PAUSED. If you pause a queue, jobs in that queue won’t begin. Jobs that are running when you pause the queue continue to run until they finish or result in an error.
Implementations
Sourceimpl UpdateQueueInput
impl UpdateQueueInput
Sourcepub fn concurrent_jobs(&self) -> Option<i32>
pub fn concurrent_jobs(&self) -> Option<i32>
Specify the maximum number of jobs your queue can process concurrently. For on-demand queues, the value you enter is constrained by your service quotas for Maximum concurrent jobs, per on-demand queue and Maximum concurrent jobs, per account. For reserved queues, update your reservation plan instead in order to increase your yearly commitment.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The new description for the queue, if you are changing it.
Sourcepub fn maximum_concurrent_feeds(&self) -> Option<i32>
pub fn maximum_concurrent_feeds(&self) -> Option<i32>
Specify the maximum number of Elemental Inference feeds MediaConvert can process concurrently.
Sourcepub fn reservation_plan_settings(&self) -> Option<&ReservationPlanSettings>
pub fn reservation_plan_settings(&self) -> Option<&ReservationPlanSettings>
The new details of your pricing plan for your reserved queue. When you set up a new pricing plan to replace an expired one, you enter into another 12-month commitment. When you add capacity to your queue by increasing the number of RTS, you extend the term of your commitment to 12 months from when you add capacity. After you make these commitments, you can’t cancel them.
Sourcepub fn status(&self) -> Option<&QueueStatus>
pub fn status(&self) -> Option<&QueueStatus>
Pause or activate a queue by changing its status between ACTIVE and PAUSED. If you pause a queue, jobs in that queue won’t begin. Jobs that are running when you pause the queue continue to run until they finish or result in an error.
Sourceimpl UpdateQueueInput
impl UpdateQueueInput
Sourcepub fn builder() -> UpdateQueueInputBuilder
pub fn builder() -> UpdateQueueInputBuilder
Creates a new builder-style object to manufacture UpdateQueueInput.