#[non_exhaustive]pub enum AacCodingMode {
AdReceiverMix,
CodingMode10,
CodingMode11,
CodingMode20,
CodingMode51,
CodingModeAuto,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against AacCodingMode, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let aaccodingmode = unimplemented!();
match aaccodingmode {
AacCodingMode::AdReceiverMix => { /* ... */ },
AacCodingMode::CodingMode10 => { /* ... */ },
AacCodingMode::CodingMode11 => { /* ... */ },
AacCodingMode::CodingMode20 => { /* ... */ },
AacCodingMode::CodingMode51 => { /* ... */ },
AacCodingMode::CodingModeAuto => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when aaccodingmode represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant AacCodingMode::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
AacCodingMode::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant AacCodingMode::NewFeature is defined.
Specifically, when aaccodingmode represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on AacCodingMode::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
The Coding mode that you specify determines the number of audio channels and the audio channel layout metadata in your AAC output. Valid coding modes depend on the Rate control mode and Profile that you select. The following list shows the number of audio channels and channel layout for each coding mode. * 1.0 Audio Description (Receiver Mix): One channel, C. Includes audio description data from your stereo input. For more information see ETSI TS 101 154 Annex E. * 1.0 Mono: One channel, C. * 2.0 Stereo: Two channels, L, R. * 5.1 Surround: Six channels, C, L, R, Ls, Rs, LFE. To follow the number of channels from your input audio, choose CODING_MODE_AUTO, and the service will automatically choose from one of the coding modes above.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AdReceiverMix
CodingMode10
CodingMode11
CodingMode20
CodingMode51
CodingModeAuto
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl AacCodingMode
impl AacCodingMode
Sourceimpl AacCodingMode
impl AacCodingMode
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.