#[non_exhaustive]pub enum Ac3DynamicRangeCompressionProfile {
FilmStandard,
None,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against Ac3DynamicRangeCompressionProfile, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let ac3dynamicrangecompressionprofile = unimplemented!();
match ac3dynamicrangecompressionprofile {
Ac3DynamicRangeCompressionProfile::FilmStandard => { /* ... */ },
Ac3DynamicRangeCompressionProfile::None => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when ac3dynamicrangecompressionprofile represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant Ac3DynamicRangeCompressionProfile::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
Ac3DynamicRangeCompressionProfile::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant Ac3DynamicRangeCompressionProfile::NewFeature is defined.
Specifically, when ac3dynamicrangecompressionprofile represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on Ac3DynamicRangeCompressionProfile::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
When you want to add Dolby dynamic range compression (DRC) signaling to your output stream, we recommend that you use the mode-specific settings instead of Dynamic range compression profile. The mode-specific settings are Dynamic range compression profile, line mode and Dynamic range compression profile, RF mode. Note that when you specify values for all three settings, MediaConvert ignores the value of this setting in favor of the mode-specific settings. If you do use this setting instead of the mode-specific settings, choose None to leave out DRC signaling. Keep the default Film standard to set the profile to Dolby’s film standard profile for all operating modes.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
FilmStandard
None
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl Ac3DynamicRangeCompressionProfile
impl Ac3DynamicRangeCompressionProfile
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.