#[non_exhaustive]pub enum Ac4CodingMode {
CodingMode20,
CodingMode32Lfe,
CodingMode514,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against Ac4CodingMode, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let ac4codingmode = unimplemented!();
match ac4codingmode {
Ac4CodingMode::CodingMode20 => { /* ... */ },
Ac4CodingMode::CodingMode32Lfe => { /* ... */ },
Ac4CodingMode::CodingMode514 => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when ac4codingmode represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant Ac4CodingMode::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
Ac4CodingMode::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant Ac4CodingMode::NewFeature is defined.
Specifically, when ac4codingmode represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on Ac4CodingMode::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
Dolby AC-4 coding mode. Determines number of channels. Maps to dlb_paec_ac4_bed_channel_config in the encoder implementation. - CODING_MODE_2_0: 2.0 (stereo) - maps to DLB_PAEC_AC4_BED_CHANNEL_CONFIG_20 - CODING_MODE_3_2_LFE: 5.1 surround - maps to DLB_PAEC_AC4_BED_CHANNEL_CONFIG_51 - CODING_MODE_5_1_4: 5.1.4 immersive - maps to DLB_PAEC_AC4_BED_CHANNEL_CONFIG_514
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CodingMode20
CodingMode32Lfe
CodingMode514
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl Ac4CodingMode
impl Ac4CodingMode
Sourceimpl Ac4CodingMode
impl Ac4CodingMode
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.