#[non_exhaustive]pub enum AudioCodec {
Show 14 variants
Aac,
Ac3,
Ac4,
Aiff,
Eac3,
Eac3Atmos,
Flac,
Mp2,
Mp3,
Opus,
Passthrough,
Vorbis,
Wav,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against AudioCodec, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let audiocodec = unimplemented!();
match audiocodec {
AudioCodec::Aac => { /* ... */ },
AudioCodec::Ac3 => { /* ... */ },
AudioCodec::Ac4 => { /* ... */ },
AudioCodec::Aiff => { /* ... */ },
AudioCodec::Eac3 => { /* ... */ },
AudioCodec::Eac3Atmos => { /* ... */ },
AudioCodec::Flac => { /* ... */ },
AudioCodec::Mp2 => { /* ... */ },
AudioCodec::Mp3 => { /* ... */ },
AudioCodec::Opus => { /* ... */ },
AudioCodec::Passthrough => { /* ... */ },
AudioCodec::Vorbis => { /* ... */ },
AudioCodec::Wav => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when audiocodec represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant AudioCodec::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
AudioCodec::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant AudioCodec::NewFeature is defined.
Specifically, when audiocodec represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on AudioCodec::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
Choose the audio codec for this output. Note that the option Dolby Digital passthrough applies only to Dolby Digital and Dolby Digital Plus audio inputs. Make sure that you choose a codec that’s supported with your output container: https://docs.aws.amazon.com/mediaconvert/latest/ug/reference-codecs-containers.html#reference-codecs-containers-output-audio For audio-only outputs, make sure that both your input audio codec and your output audio codec are supported for audio-only workflows. For more information, see: https://docs.aws.amazon.com/mediaconvert/latest/ug/reference-codecs-containers-input.html#reference-codecs-containers-input-audio-only and https://docs.aws.amazon.com/mediaconvert/latest/ug/reference-codecs-containers.html#audio-only-output
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Aac
Ac3
Ac4
Aiff
Eac3
Eac3Atmos
Flac
Mp2
Mp3
Opus
Passthrough
Vorbis
Wav
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl AudioCodec
impl AudioCodec
Sourceimpl AudioCodec
impl AudioCodec
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.