#[non_exhaustive]pub enum AudioSelectorType {
AllPcm,
HlsRenditionGroup,
LanguageCode,
Pid,
Stream,
Track,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against AudioSelectorType, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let audioselectortype = unimplemented!();
match audioselectortype {
AudioSelectorType::AllPcm => { /* ... */ },
AudioSelectorType::HlsRenditionGroup => { /* ... */ },
AudioSelectorType::LanguageCode => { /* ... */ },
AudioSelectorType::Pid => { /* ... */ },
AudioSelectorType::Stream => { /* ... */ },
AudioSelectorType::Track => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when audioselectortype represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant AudioSelectorType::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
AudioSelectorType::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant AudioSelectorType::NewFeature is defined.
Specifically, when audioselectortype represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on AudioSelectorType::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
Specify how MediaConvert selects audio content within your input. The default is Track. PID: Select audio by specifying the Packet Identifier (PID) values for MPEG Transport Stream inputs. Use this when you know the exact PID values of your audio streams. Track: Default. Select audio by track number. This is the most common option and works with most input container formats. If more types of audio data get recognized in the future, these numberings may shift, but the numberings used for Stream mode will not. Language code: Select audio by language using an ISO 639-2 or ISO 639-3 three-letter code in all capital letters. Use this when your source has embedded language metadata and you want to select tracks based on their language. HLS rendition group: Select audio from an HLS rendition group. Use this when your input is an HLS package with multiple audio renditions and you want to select specific rendition groups. All PCM: Select all uncompressed PCM audio tracks from your input automatically. This is useful when you want to include all PCM audio tracks without specifying individual track numbers. Stream: Select audio by stream number. Stream numbers include all tracks in the source file, regardless of type, and correspond to either the order of tracks in the file, or if applicable, the stream number metadata of the track. Although all tracks count toward these stream numbers, in this audio selector context, only the stream number of a track containing audio data may be used. If your source file contains a track which is not recognized by the service, then the corresponding stream number will still be reserved for future use. If more types of audio data get recognized in the future, these numberings will not shift.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AllPcm
HlsRenditionGroup
LanguageCode
Pid
Stream
Track
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl AudioSelectorType
impl AudioSelectorType
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.