AudioTypeControl

Enum AudioTypeControl 

#[non_exhaustive]
pub enum AudioTypeControl { FollowInput, UseConfigured, Unknown(UnknownVariantValue), }
When writing a match expression against AudioTypeControl, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.

Here is an example of how you can make a match expression forward-compatible:

# let audiotypecontrol = unimplemented!();
match audiotypecontrol {
    AudioTypeControl::FollowInput => { /* ... */ },
    AudioTypeControl::UseConfigured => { /* ... */ },
    other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
    _ => { /* ... */ },
}

The above code demonstrates that when audiotypecontrol represents NewFeature, the execution path will lead to the second last match arm, even though the enum does not contain a variant AudioTypeControl::NewFeature in the current version of SDK. The reason is that the variable other, created by the @ operator, is bound to AudioTypeControl::Unknown(UnknownVariantValue("NewFeature".to_owned())) and calling as_str on it yields "NewFeature". This match expression is forward-compatible when executed with a newer version of SDK where the variant AudioTypeControl::NewFeature is defined. Specifically, when audiotypecontrol represents NewFeature, the execution path will hit the second last match arm as before by virtue of calling as_str on AudioTypeControl::NewFeature also yielding "NewFeature".

Explicitly matching on the Unknown variant should be avoided for two reasons:

  • The inner data UnknownVariantValue is opaque, and no further information can be extracted.
  • It might inadvertently shadow other intended match arms.

When set to FOLLOW_INPUT, if the input contains an ISO 639 audio_type, then that value is passed through to the output. If the input contains no ISO 639 audio_type, the value in Audio Type is included in the output. Otherwise the value in Audio Type is included in the output. Note that this field and audioType are both ignored if audioDescriptionBroadcasterMix is set to BROADCASTER_MIXED_AD.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


FollowInput



UseConfigured



Unknown(UnknownVariantValue)

👎Deprecated:

Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.

Unknown contains new variants that have been added since this code was generated.

Implementations

Source

impl AudioTypeControl

pub fn as_str(&self) -> &str

Returns the &str value of the enum member.

pub const fn values() -> &'static [&'static str]

Returns all the &str representations of the enum members.

Source

impl AudioTypeControl

pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>

Parses the enum value while disallowing unknown variants.

Unknown variants will result in an error.