#[non_exhaustive]pub enum Av1SpatialAdaptiveQuantization {
Disabled,
Enabled,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against Av1SpatialAdaptiveQuantization, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let av1spatialadaptivequantization = unimplemented!();
match av1spatialadaptivequantization {
Av1SpatialAdaptiveQuantization::Disabled => { /* ... */ },
Av1SpatialAdaptiveQuantization::Enabled => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when av1spatialadaptivequantization represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant Av1SpatialAdaptiveQuantization::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
Av1SpatialAdaptiveQuantization::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant Av1SpatialAdaptiveQuantization::NewFeature is defined.
Specifically, when av1spatialadaptivequantization represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on Av1SpatialAdaptiveQuantization::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
Keep the default value, Enabled, to adjust quantization within each frame based on spatial variation of content complexity. When you enable this feature, the encoder uses fewer bits on areas that can sustain more distortion with no noticeable visual degradation and uses more bits on areas where any small distortion will be noticeable. For example, complex textured blocks are encoded with fewer bits and smooth textured blocks are encoded with more bits. Enabling this feature will almost always improve your video quality. Note, though, that this feature doesn’t take into account where the viewer’s attention is likely to be. If viewers are likely to be focusing their attention on a part of the screen with a lot of complex texture, you might choose to disable this feature. Related setting: When you enable spatial adaptive quantization, set the value for Adaptive quantization depending on your content. For homogeneous content, such as cartoons and video games, set it to Low. For content with a wider variety of textures, set it to High or Higher.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Disabled
Enabled
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl Av1SpatialAdaptiveQuantization
impl Av1SpatialAdaptiveQuantization
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.