#[non_exhaustive]pub enum CaptionDestinationType {
Show 13 variants
BurnIn,
DvbSub,
Embedded,
EmbeddedPlusScte20,
Imsc,
Scc,
Scte20PlusEmbedded,
Smi,
Srt,
Teletext,
Ttml,
Webvtt,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against CaptionDestinationType, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let captiondestinationtype = unimplemented!();
match captiondestinationtype {
CaptionDestinationType::BurnIn => { /* ... */ },
CaptionDestinationType::DvbSub => { /* ... */ },
CaptionDestinationType::Embedded => { /* ... */ },
CaptionDestinationType::EmbeddedPlusScte20 => { /* ... */ },
CaptionDestinationType::Imsc => { /* ... */ },
CaptionDestinationType::Scc => { /* ... */ },
CaptionDestinationType::Scte20PlusEmbedded => { /* ... */ },
CaptionDestinationType::Smi => { /* ... */ },
CaptionDestinationType::Srt => { /* ... */ },
CaptionDestinationType::Teletext => { /* ... */ },
CaptionDestinationType::Ttml => { /* ... */ },
CaptionDestinationType::Webvtt => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when captiondestinationtype represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant CaptionDestinationType::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
CaptionDestinationType::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant CaptionDestinationType::NewFeature is defined.
Specifically, when captiondestinationtype represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on CaptionDestinationType::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
Specify the format for this set of captions on this output. The default format is embedded without SCTE-20. Note that your choice of video output container constrains your choice of output captions format. For more information, see https://docs.aws.amazon.com/mediaconvert/latest/ug/captions-support-tables.html. If you are using SCTE-20 and you want to create an output that complies with the SCTE-43 spec, choose SCTE-20 plus embedded. To create a non-compliant output where the embedded captions come first, choose Embedded plus SCTE-20.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BurnIn
DvbSub
Embedded
EmbeddedPlusScte20
Imsc
Scc
Scte20PlusEmbedded
Smi
Srt
Teletext
Ttml
Webvtt
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl CaptionDestinationType
impl CaptionDestinationType
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.