#[non_exhaustive]pub enum CmafClientCache {
Disabled,
Enabled,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against CmafClientCache, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let cmafclientcache = unimplemented!();
match cmafclientcache {
CmafClientCache::Disabled => { /* ... */ },
CmafClientCache::Enabled => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when cmafclientcache represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant CmafClientCache::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
CmafClientCache::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant CmafClientCache::NewFeature is defined.
Specifically, when cmafclientcache represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on CmafClientCache::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
Disable this setting only when your workflow requires the #EXT-X-ALLOW-CACHE:no tag. Otherwise, keep the default value Enabled and control caching in your video distribution set up. For example, use the Cache-Control http header.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Disabled
Enabled
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl CmafClientCache
impl CmafClientCache
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.