#[non_exhaustive]pub enum DvbSubSubtitleFallbackFont {
BestMatch,
MonospacedSansserif,
MonospacedSerif,
ProportionalSansserif,
ProportionalSerif,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against DvbSubSubtitleFallbackFont, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let dvbsubsubtitlefallbackfont = unimplemented!();
match dvbsubsubtitlefallbackfont {
DvbSubSubtitleFallbackFont::BestMatch => { /* ... */ },
DvbSubSubtitleFallbackFont::MonospacedSansserif => { /* ... */ },
DvbSubSubtitleFallbackFont::MonospacedSerif => { /* ... */ },
DvbSubSubtitleFallbackFont::ProportionalSansserif => { /* ... */ },
DvbSubSubtitleFallbackFont::ProportionalSerif => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when dvbsubsubtitlefallbackfont represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant DvbSubSubtitleFallbackFont::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
DvbSubSubtitleFallbackFont::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant DvbSubSubtitleFallbackFont::NewFeature is defined.
Specifically, when dvbsubsubtitlefallbackfont represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on DvbSubSubtitleFallbackFont::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
Specify the font that you want the service to use for your burn in captions when your input captions specify a font that MediaConvert doesn’t support. When you set Fallback font to best match, or leave blank, MediaConvert uses a supported font that most closely matches the font that your input captions specify. When there are multiple unsupported fonts in your input captions, MediaConvert matches each font with the supported font that matches best. When you explicitly choose a replacement font, MediaConvert uses that font to replace all unsupported fonts from your input.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BestMatch
MonospacedSansserif
MonospacedSerif
ProportionalSansserif
ProportionalSerif
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl DvbSubSubtitleFallbackFont
impl DvbSubSubtitleFallbackFont
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.