#[non_exhaustive]pub enum H264FlickerAdaptiveQuantization {
Disabled,
Enabled,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against H264FlickerAdaptiveQuantization, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let h264flickeradaptivequantization = unimplemented!();
match h264flickeradaptivequantization {
H264FlickerAdaptiveQuantization::Disabled => { /* ... */ },
H264FlickerAdaptiveQuantization::Enabled => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when h264flickeradaptivequantization represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant H264FlickerAdaptiveQuantization::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
H264FlickerAdaptiveQuantization::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant H264FlickerAdaptiveQuantization::NewFeature is defined.
Specifically, when h264flickeradaptivequantization represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on H264FlickerAdaptiveQuantization::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
Only use this setting when you change the default value, AUTO, for the setting H264AdaptiveQuantization. When you keep all defaults, excluding H264AdaptiveQuantization and all other adaptive quantization from your JSON job specification, MediaConvert automatically applies the best types of quantization for your video content. When you set H264AdaptiveQuantization to a value other than AUTO, the default value for H264FlickerAdaptiveQuantization is Disabled. Change this value to Enabled to reduce I-frame pop. I-frame pop appears as a visual flicker that can arise when the encoder saves bits by copying some macroblocks many times from frame to frame, and then refreshes them at the I-frame. When you enable this setting, the encoder updates these macroblocks slightly more often to smooth out the flicker. To manually enable or disable H264FlickerAdaptiveQuantization, you must set Adaptive quantization to a value other than AUTO.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Disabled
Enabled
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl H264FlickerAdaptiveQuantization
impl H264FlickerAdaptiveQuantization
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.