#[non_exhaustive]pub enum H264TemporalAdaptiveQuantization {
Disabled,
Enabled,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against H264TemporalAdaptiveQuantization, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let h264temporaladaptivequantization = unimplemented!();
match h264temporaladaptivequantization {
H264TemporalAdaptiveQuantization::Disabled => { /* ... */ },
H264TemporalAdaptiveQuantization::Enabled => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when h264temporaladaptivequantization represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant H264TemporalAdaptiveQuantization::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
H264TemporalAdaptiveQuantization::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant H264TemporalAdaptiveQuantization::NewFeature is defined.
Specifically, when h264temporaladaptivequantization represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on H264TemporalAdaptiveQuantization::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
Only use this setting when you change the default value, AUTO, for the setting H264AdaptiveQuantization. When you keep all defaults, excluding H264AdaptiveQuantization and all other adaptive quantization from your JSON job specification, MediaConvert automatically applies the best types of quantization for your video content. When you set H264AdaptiveQuantization to a value other than AUTO, the default value for H264TemporalAdaptiveQuantization is Enabled. Keep this default value to adjust quantization within each frame based on temporal variation of content complexity. When you enable this feature, the encoder uses fewer bits on areas of the frame that aren’t moving and uses more bits on complex objects with sharp edges that move a lot. For example, this feature improves the readability of text tickers on newscasts and scoreboards on sports matches. Enabling this feature will almost always improve your video quality. Note, though, that this feature doesn’t take into account where the viewer’s attention is likely to be. If viewers are likely to be focusing their attention on a part of the screen that doesn’t have moving objects with sharp edges, such as sports athletes’ faces, you might choose to set H264TemporalAdaptiveQuantization to Disabled. Related setting: When you enable temporal quantization, adjust the strength of the filter with the setting Adaptive quantization. To manually enable or disable H264TemporalAdaptiveQuantization, you must set Adaptive quantization to a value other than AUTO.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Disabled
Enabled
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl H264TemporalAdaptiveQuantization
impl H264TemporalAdaptiveQuantization
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.