#[non_exhaustive]pub enum HlsCaptionLanguageSetting {
Insert,
None,
Omit,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against HlsCaptionLanguageSetting, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let hlscaptionlanguagesetting = unimplemented!();
match hlscaptionlanguagesetting {
HlsCaptionLanguageSetting::Insert => { /* ... */ },
HlsCaptionLanguageSetting::None => { /* ... */ },
HlsCaptionLanguageSetting::Omit => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when hlscaptionlanguagesetting represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant HlsCaptionLanguageSetting::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
HlsCaptionLanguageSetting::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant HlsCaptionLanguageSetting::NewFeature is defined.
Specifically, when hlscaptionlanguagesetting represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on HlsCaptionLanguageSetting::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
Applies only to 608 Embedded output captions. Insert: Include CLOSED-CAPTIONS lines in the manifest. Specify at least one language in the CC1 Language Code field. One CLOSED-CAPTION line is added for each Language Code you specify. Make sure to specify the languages in the order in which they appear in the original source (if the source is embedded format) or the order of the caption selectors (if the source is other than embedded). Otherwise, languages in the manifest will not match up properly with the output captions. None: Include CLOSED-CAPTIONS=NONE line in the manifest. Omit: Omit any CLOSED-CAPTIONS line from the manifest.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Insert
None
Omit
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl HlsCaptionLanguageSetting
impl HlsCaptionLanguageSetting
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.