#[non_exhaustive]pub enum InputRotate {
Auto,
Degrees180,
Degrees270,
Degrees90,
Degree0,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against InputRotate, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let inputrotate = unimplemented!();
match inputrotate {
InputRotate::Auto => { /* ... */ },
InputRotate::Degrees180 => { /* ... */ },
InputRotate::Degrees270 => { /* ... */ },
InputRotate::Degrees90 => { /* ... */ },
InputRotate::Degree0 => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when inputrotate represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant InputRotate::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
InputRotate::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant InputRotate::NewFeature is defined.
Specifically, when inputrotate represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on InputRotate::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
Use Rotate to specify how the service rotates your video. You can choose automatic rotation or specify a rotation. You can specify a clockwise rotation of 0, 90, 180, or 270 degrees. If your input video container is .mov or .mp4 and your input has rotation metadata, you can choose Automatic to have the service rotate your video according to the rotation specified in the metadata. The rotation must be within one degree of 90, 180, or 270 degrees. If the rotation metadata specifies any other rotation, the service will default to no rotation. By default, the service does no rotation, even if your input video has rotation metadata. The service doesn’t pass through rotation metadata.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Auto
Degrees180
Degrees270
Degrees90
Degree0
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl InputRotate
impl InputRotate
Sourceimpl InputRotate
impl InputRotate
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.