#[non_exhaustive]pub enum InputSampleRange {
Follow,
FullRange,
LimitedRange,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against InputSampleRange, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let inputsamplerange = unimplemented!();
match inputsamplerange {
InputSampleRange::Follow => { /* ... */ },
InputSampleRange::FullRange => { /* ... */ },
InputSampleRange::LimitedRange => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when inputsamplerange represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant InputSampleRange::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
InputSampleRange::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant InputSampleRange::NewFeature is defined.
Specifically, when inputsamplerange represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on InputSampleRange::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
If the sample range metadata in your input video is accurate, or if you don’t know about sample range, keep the default value, Follow, for this setting. When you do, the service automatically detects your input sample range. If your input video has metadata indicating the wrong sample range, specify the accurate sample range here. When you do, MediaConvert ignores any sample range information in the input metadata. Regardless of whether MediaConvert uses the input sample range or the sample range that you specify, MediaConvert uses the sample range for transcoding and also writes it to the output metadata.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Follow
FullRange
LimitedRange
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl InputSampleRange
impl InputSampleRange
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.