#[non_exhaustive]pub enum InputScanType {
Auto,
Psf,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against InputScanType, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let inputscantype = unimplemented!();
match inputscantype {
InputScanType::Auto => { /* ... */ },
InputScanType::Psf => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when inputscantype represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant InputScanType::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
InputScanType::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant InputScanType::NewFeature is defined.
Specifically, when inputscantype represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on InputScanType::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
When you have a progressive segmented frame (PsF) input, use this setting to flag the input as PsF. MediaConvert doesn’t automatically detect PsF. Therefore, flagging your input as PsF results in better preservation of video quality when you do deinterlacing and frame rate conversion. If you don’t specify, the default value is Auto. Auto is the correct setting for all inputs that are not PsF. Don’t set this value to PsF when your input is interlaced. Doing so creates horizontal interlacing artifacts.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Auto
Psf
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl InputScanType
impl InputScanType
Sourceimpl InputScanType
impl InputScanType
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.