#[non_exhaustive]pub enum S3ServerSideEncryptionType {
ServerSideEncryptionKms,
ServerSideEncryptionS3,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against S3ServerSideEncryptionType, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let s3serversideencryptiontype = unimplemented!();
match s3serversideencryptiontype {
S3ServerSideEncryptionType::ServerSideEncryptionKms => { /* ... */ },
S3ServerSideEncryptionType::ServerSideEncryptionS3 => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when s3serversideencryptiontype represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant S3ServerSideEncryptionType::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
S3ServerSideEncryptionType::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant S3ServerSideEncryptionType::NewFeature is defined.
Specifically, when s3serversideencryptiontype represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on S3ServerSideEncryptionType::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
Specify how you want your data keys managed. AWS uses data keys to encrypt your content. AWS also encrypts the data keys themselves, using a customer master key (CMK), and then stores the encrypted data keys alongside your encrypted content. Use this setting to specify which AWS service manages the CMK. For simplest set up, choose Amazon S3. If you want your master key to be managed by AWS Key Management Service (KMS), choose AWS KMS. By default, when you choose AWS KMS, KMS uses the AWS managed customer master key (CMK) associated with Amazon S3 to encrypt your data keys. You can optionally choose to specify a different, customer managed CMK. Do so by specifying the Amazon Resource Name (ARN) of the key for the setting KMS ARN.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ServerSideEncryptionKms
ServerSideEncryptionS3
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl S3ServerSideEncryptionType
impl S3ServerSideEncryptionType
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.