SampleRangeConversion

Enum SampleRangeConversion 

#[non_exhaustive]
pub enum SampleRangeConversion { LimitedRangeClip, LimitedRangeSqueeze, None, Unknown(UnknownVariantValue), }
When writing a match expression against SampleRangeConversion, it is important to ensure your code is forward-compatible. That is, if a match arm handles a case for a feature that is supported by the service but has not been represented as an enum variant in a current version of SDK, your code should continue to work when you upgrade SDK to a future version in which the enum does include a variant for that feature.

Here is an example of how you can make a match expression forward-compatible:

# let samplerangeconversion = unimplemented!();
match samplerangeconversion {
    SampleRangeConversion::LimitedRangeClip => { /* ... */ },
    SampleRangeConversion::LimitedRangeSqueeze => { /* ... */ },
    SampleRangeConversion::None => { /* ... */ },
    other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
    _ => { /* ... */ },
}

The above code demonstrates that when samplerangeconversion represents NewFeature, the execution path will lead to the second last match arm, even though the enum does not contain a variant SampleRangeConversion::NewFeature in the current version of SDK. The reason is that the variable other, created by the @ operator, is bound to SampleRangeConversion::Unknown(UnknownVariantValue("NewFeature".to_owned())) and calling as_str on it yields "NewFeature". This match expression is forward-compatible when executed with a newer version of SDK where the variant SampleRangeConversion::NewFeature is defined. Specifically, when samplerangeconversion represents NewFeature, the execution path will hit the second last match arm as before by virtue of calling as_str on SampleRangeConversion::NewFeature also yielding "NewFeature".

Explicitly matching on the Unknown variant should be avoided for two reasons:

  • The inner data UnknownVariantValue is opaque, and no further information can be extracted.
  • It might inadvertently shadow other intended match arms.

Specify how MediaConvert limits the color sample range for this output. To create a limited range output from a full range input: Choose Limited range squeeze. For full range inputs, MediaConvert performs a linear offset to color samples equally across all pixels and frames. Color samples in 10-bit outputs are limited to 64 through 940, and 8-bit outputs are limited to 16 through 235. Note: For limited range inputs, values for color samples are passed through to your output unchanged. MediaConvert does not limit the sample range. To correct pixels in your input that are out of range or out of gamut: Choose Limited range clip. Use for broadcast applications. MediaConvert conforms any pixels outside of the values that you specify under Minimum YUV and Maximum YUV to limited range bounds. MediaConvert also corrects any YUV values that, when converted to RGB, would be outside the bounds you specify under Minimum RGB tolerance and Maximum RGB tolerance. With either limited range conversion, MediaConvert writes the sample range metadata in the output.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


LimitedRangeClip



LimitedRangeSqueeze



None



Unknown(UnknownVariantValue)

👎Deprecated:

Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.

Unknown contains new variants that have been added since this code was generated.

Implementations

Source

impl SampleRangeConversion

pub fn as_str(&self) -> &str

Returns the &str value of the enum member.

pub const fn values() -> &'static [&'static str]

Returns all the &str representations of the enum members.

Source

impl SampleRangeConversion

pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>

Parses the enum value while disallowing unknown variants.

Unknown variants will result in an error.