#[non_exhaustive]pub enum StatusUpdateInterval {
Show 16 variants
Seconds10,
Seconds12,
Seconds120,
Seconds15,
Seconds180,
Seconds20,
Seconds240,
Seconds30,
Seconds300,
Seconds360,
Seconds420,
Seconds480,
Seconds540,
Seconds60,
Seconds600,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against StatusUpdateInterval, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let statusupdateinterval = unimplemented!();
match statusupdateinterval {
StatusUpdateInterval::Seconds10 => { /* ... */ },
StatusUpdateInterval::Seconds12 => { /* ... */ },
StatusUpdateInterval::Seconds120 => { /* ... */ },
StatusUpdateInterval::Seconds15 => { /* ... */ },
StatusUpdateInterval::Seconds180 => { /* ... */ },
StatusUpdateInterval::Seconds20 => { /* ... */ },
StatusUpdateInterval::Seconds240 => { /* ... */ },
StatusUpdateInterval::Seconds30 => { /* ... */ },
StatusUpdateInterval::Seconds300 => { /* ... */ },
StatusUpdateInterval::Seconds360 => { /* ... */ },
StatusUpdateInterval::Seconds420 => { /* ... */ },
StatusUpdateInterval::Seconds480 => { /* ... */ },
StatusUpdateInterval::Seconds540 => { /* ... */ },
StatusUpdateInterval::Seconds60 => { /* ... */ },
StatusUpdateInterval::Seconds600 => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when statusupdateinterval represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant StatusUpdateInterval::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
StatusUpdateInterval::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant StatusUpdateInterval::NewFeature is defined.
Specifically, when statusupdateinterval represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on StatusUpdateInterval::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
Specify how often MediaConvert sends STATUS_UPDATE events to Amazon CloudWatch Events. Set the interval, in seconds, between status updates. MediaConvert sends an update at this interval from the time the service begins processing your job to the time it completes the transcode or encounters an error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Seconds10
Seconds12
Seconds120
Seconds15
Seconds180
Seconds20
Seconds240
Seconds30
Seconds300
Seconds360
Seconds420
Seconds480
Seconds540
Seconds60
Seconds600
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl StatusUpdateInterval
impl StatusUpdateInterval
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.