#[non_exhaustive]pub enum UncompressedScanTypeConversionMode {
Interlaced,
InterlacedOptimize,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against UncompressedScanTypeConversionMode, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let uncompressedscantypeconversionmode = unimplemented!();
match uncompressedscantypeconversionmode {
UncompressedScanTypeConversionMode::Interlaced => { /* ... */ },
UncompressedScanTypeConversionMode::InterlacedOptimize => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when uncompressedscantypeconversionmode represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant UncompressedScanTypeConversionMode::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
UncompressedScanTypeConversionMode::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant UncompressedScanTypeConversionMode::NewFeature is defined.
Specifically, when uncompressedscantypeconversionmode represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on UncompressedScanTypeConversionMode::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
Use this setting for interlaced outputs, when your output frame rate is half of your input frame rate. In this situation, choose Optimized interlacing to create a better quality interlaced output. In this case, each progressive frame from the input corresponds to an interlaced field in the output. Keep the default value, Basic interlacing, for all other output frame rates. With basic interlacing, MediaConvert performs any frame rate conversion first and then interlaces the frames. When you choose Optimized interlacing and you set your output frame rate to a value that isn’t suitable for optimized interlacing, MediaConvert automatically falls back to basic interlacing. Required settings: To use optimized interlacing, you must set Telecine to None or Soft. You can’t use optimized interlacing for hard telecine outputs. You must also set Interlace mode to a value other than Progressive.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Interlaced
InterlacedOptimize
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl UncompressedScanTypeConversionMode
impl UncompressedScanTypeConversionMode
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.