#[non_exhaustive]pub enum VideoTimecodeInsertion {
Disabled,
PicTimingSei,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against VideoTimecodeInsertion, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let videotimecodeinsertion = unimplemented!();
match videotimecodeinsertion {
VideoTimecodeInsertion::Disabled => { /* ... */ },
VideoTimecodeInsertion::PicTimingSei => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when videotimecodeinsertion represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant VideoTimecodeInsertion::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
VideoTimecodeInsertion::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant VideoTimecodeInsertion::NewFeature is defined.
Specifically, when videotimecodeinsertion represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on VideoTimecodeInsertion::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
Applies only to H.264, H.265, MPEG2, and ProRes outputs. Only enable Timecode insertion when the input frame rate is identical to the output frame rate. To include timecodes in this output, set Timecode insertion to PIC_TIMING_SEI. To leave them out, set it to DISABLED. Default is DISABLED. When the service inserts timecodes in an output, by default, it uses any embedded timecodes from the input. If none are present, the service will set the timecode for the first output frame to zero. To change this default behavior, adjust the settings under Timecode configuration. In the console, these settings are located under Job > Job settings > Timecode configuration. Note - Timecode source under input settings does not affect the timecodes that are inserted in the output. Source under Job settings > Timecode configuration does.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Disabled
PicTimingSei
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl VideoTimecodeInsertion
impl VideoTimecodeInsertion
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.