#[non_exhaustive]pub struct AudioNormalizationSettings {
pub algorithm: Option<AudioNormalizationAlgorithm>,
pub algorithm_control: Option<AudioNormalizationAlgorithmControl>,
pub correction_gate_level: Option<i32>,
pub loudness_logging: Option<AudioNormalizationLoudnessLogging>,
pub peak_calculation: Option<AudioNormalizationPeakCalculation>,
pub target_lkfs: Option<f64>,
pub true_peak_limiter_threshold: Option<f64>,
}Expand description
Advanced audio normalization settings. Ignore these settings unless you need to comply with a loudness standard.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.algorithm: Option<AudioNormalizationAlgorithm>Choose one of the following audio normalization algorithms: ITU-R BS.1770-1: Ungated loudness. A measurement of ungated average loudness for an entire piece of content, suitable for measurement of short-form content under ATSC recommendation A/85. Supports up to 5.1 audio channels. ITU-R BS.1770-2: Gated loudness. A measurement of gated average loudness compliant with the requirements of EBU-R128. Supports up to 5.1 audio channels. ITU-R BS.1770-3: Modified peak. The same loudness measurement algorithm as 1770-2, with an updated true peak measurement. ITU-R BS.1770-4: Higher channel count. Allows for more audio channels than the other algorithms, including configurations such as 7.1.
algorithm_control: Option<AudioNormalizationAlgorithmControl>When enabled the output audio is corrected using the chosen algorithm. If disabled, the audio will be measured but not adjusted.
correction_gate_level: Option<i32>Content measuring above this level will be corrected to the target level. Content measuring below this level will not be corrected.
loudness_logging: Option<AudioNormalizationLoudnessLogging>If set to LOG, log each output’s audio track loudness to a CSV file.
peak_calculation: Option<AudioNormalizationPeakCalculation>If set to TRUE_PEAK, calculate and log the TruePeak for each output’s audio track loudness.
target_lkfs: Option<f64>When you use Audio normalization, optionally use this setting to specify a target loudness. If you don’t specify a value here, the encoder chooses a value for you, based on the algorithm that you choose for Algorithm. If you choose algorithm 1770-1, the encoder will choose -24 LKFS; otherwise, the encoder will choose -23 LKFS.
true_peak_limiter_threshold: Option<f64>Specify the True-peak limiter threshold in decibels relative to full scale (dBFS). The peak inter-audio sample loudness in your output will be limited to the value that you specify, without affecting the overall target LKFS. Enter a value from 0 to -8. Leave blank to use the default value 0.
Implementations
Sourceimpl AudioNormalizationSettings
impl AudioNormalizationSettings
Sourcepub fn algorithm(&self) -> Option<&AudioNormalizationAlgorithm>
pub fn algorithm(&self) -> Option<&AudioNormalizationAlgorithm>
Choose one of the following audio normalization algorithms: ITU-R BS.1770-1: Ungated loudness. A measurement of ungated average loudness for an entire piece of content, suitable for measurement of short-form content under ATSC recommendation A/85. Supports up to 5.1 audio channels. ITU-R BS.1770-2: Gated loudness. A measurement of gated average loudness compliant with the requirements of EBU-R128. Supports up to 5.1 audio channels. ITU-R BS.1770-3: Modified peak. The same loudness measurement algorithm as 1770-2, with an updated true peak measurement. ITU-R BS.1770-4: Higher channel count. Allows for more audio channels than the other algorithms, including configurations such as 7.1.
Sourcepub fn algorithm_control(&self) -> Option<&AudioNormalizationAlgorithmControl>
pub fn algorithm_control(&self) -> Option<&AudioNormalizationAlgorithmControl>
When enabled the output audio is corrected using the chosen algorithm. If disabled, the audio will be measured but not adjusted.
Sourcepub fn correction_gate_level(&self) -> Option<i32>
pub fn correction_gate_level(&self) -> Option<i32>
Content measuring above this level will be corrected to the target level. Content measuring below this level will not be corrected.
Sourcepub fn loudness_logging(&self) -> Option<&AudioNormalizationLoudnessLogging>
pub fn loudness_logging(&self) -> Option<&AudioNormalizationLoudnessLogging>
If set to LOG, log each output’s audio track loudness to a CSV file.
Sourcepub fn peak_calculation(&self) -> Option<&AudioNormalizationPeakCalculation>
pub fn peak_calculation(&self) -> Option<&AudioNormalizationPeakCalculation>
If set to TRUE_PEAK, calculate and log the TruePeak for each output’s audio track loudness.
Sourcepub fn target_lkfs(&self) -> Option<f64>
pub fn target_lkfs(&self) -> Option<f64>
When you use Audio normalization, optionally use this setting to specify a target loudness. If you don’t specify a value here, the encoder chooses a value for you, based on the algorithm that you choose for Algorithm. If you choose algorithm 1770-1, the encoder will choose -24 LKFS; otherwise, the encoder will choose -23 LKFS.
Sourcepub fn true_peak_limiter_threshold(&self) -> Option<f64>
pub fn true_peak_limiter_threshold(&self) -> Option<f64>
Specify the True-peak limiter threshold in decibels relative to full scale (dBFS). The peak inter-audio sample loudness in your output will be limited to the value that you specify, without affecting the overall target LKFS. Enter a value from 0 to -8. Leave blank to use the default value 0.
Sourceimpl AudioNormalizationSettings
impl AudioNormalizationSettings
Sourcepub fn builder() -> AudioNormalizationSettingsBuilder
pub fn builder() -> AudioNormalizationSettingsBuilder
Creates a new builder-style object to manufacture AudioNormalizationSettings.