#[non_exhaustive]pub struct AutomatedEncodingSettings {
pub abr_settings: Option<AutomatedAbrSettings>,
}Expand description
Use automated encoding to have MediaConvert choose your encoding settings for you, based on characteristics of your input video.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.abr_settings: Option<AutomatedAbrSettings>Use automated ABR to have MediaConvert set up the renditions in your ABR package for you automatically, based on characteristics of your input video. This feature optimizes video quality while minimizing the overall size of your ABR package.
Implementations
Sourceimpl AutomatedEncodingSettings
impl AutomatedEncodingSettings
Sourcepub fn abr_settings(&self) -> Option<&AutomatedAbrSettings>
pub fn abr_settings(&self) -> Option<&AutomatedAbrSettings>
Use automated ABR to have MediaConvert set up the renditions in your ABR package for you automatically, based on characteristics of your input video. This feature optimizes video quality while minimizing the overall size of your ABR package.
Sourceimpl AutomatedEncodingSettings
impl AutomatedEncodingSettings
Sourcepub fn builder() -> AutomatedEncodingSettingsBuilder
pub fn builder() -> AutomatedEncodingSettingsBuilder
Creates a new builder-style object to manufacture AutomatedEncodingSettings.