#[non_exhaustive]pub struct ChannelMapping {
pub output_channels: Option<Vec<OutputChannelMapping>>,
}Expand description
Channel mapping contains the group of fields that hold the remixing value for each channel, in dB. Specify remix values to indicate how much of the content from your input audio channel you want in your output audio channels. Each instance of the InputChannels or InputChannelsFineTune array specifies these values for one output channel. Use one instance of this array for each output channel. In the console, each array corresponds to a column in the graphical depiction of the mapping matrix. The rows of the graphical matrix correspond to input channels. Valid values are within the range from -60 (mute) through 6. A setting of 0 passes the input channel unchanged to the output channel (no attenuation or amplification). Use InputChannels or InputChannelsFineTune to specify your remix values. Don’t use both.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.output_channels: Option<Vec<OutputChannelMapping>>In your JSON job specification, include one child of OutputChannels for each audio channel that you want in your output. Each child should contain one instance of InputChannels or InputChannelsFineTune.
Implementations
Sourceimpl ChannelMapping
impl ChannelMapping
Sourcepub fn output_channels(&self) -> &[OutputChannelMapping]
pub fn output_channels(&self) -> &[OutputChannelMapping]
In your JSON job specification, include one child of OutputChannels for each audio channel that you want in your output. Each child should contain one instance of InputChannels or InputChannelsFineTune.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .output_channels.is_none().
Sourceimpl ChannelMapping
impl ChannelMapping
Sourcepub fn builder() -> ChannelMappingBuilder
pub fn builder() -> ChannelMappingBuilder
Creates a new builder-style object to manufacture ChannelMapping.