#[non_exhaustive]pub struct EmbeddedSourceSettings {
pub convert608_to708: Option<EmbeddedConvert608To708>,
pub source608_channel_number: Option<i32>,
pub source608_track_number: Option<i32>,
pub terminate_captions: Option<EmbeddedTerminateCaptions>,
}Expand description
Settings for embedded captions Source
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.convert608_to708: Option<EmbeddedConvert608To708>Specify whether this set of input captions appears in your outputs in both 608 and 708 format. If you choose Upconvert, MediaConvert includes the captions data in two ways: it passes the 608 data through using the 608 compatibility bytes fields of the 708 wrapper, and it also translates the 608 data into 708.
source608_channel_number: Option<i32>Specifies the 608/708 channel number within the video track from which to extract captions. Unused for passthrough.
source608_track_number: Option<i32>Specifies the video track index used for extracting captions. The system only supports one input video track, so this should always be set to ‘1’.
terminate_captions: Option<EmbeddedTerminateCaptions>By default, the service terminates any unterminated captions at the end of each input. If you want the caption to continue onto your next input, disable this setting.
Implementations
Sourceimpl EmbeddedSourceSettings
impl EmbeddedSourceSettings
Sourcepub fn convert608_to708(&self) -> Option<&EmbeddedConvert608To708>
pub fn convert608_to708(&self) -> Option<&EmbeddedConvert608To708>
Specify whether this set of input captions appears in your outputs in both 608 and 708 format. If you choose Upconvert, MediaConvert includes the captions data in two ways: it passes the 608 data through using the 608 compatibility bytes fields of the 708 wrapper, and it also translates the 608 data into 708.
Sourcepub fn source608_channel_number(&self) -> Option<i32>
pub fn source608_channel_number(&self) -> Option<i32>
Specifies the 608/708 channel number within the video track from which to extract captions. Unused for passthrough.
Sourcepub fn source608_track_number(&self) -> Option<i32>
pub fn source608_track_number(&self) -> Option<i32>
Specifies the video track index used for extracting captions. The system only supports one input video track, so this should always be set to ‘1’.
Sourcepub fn terminate_captions(&self) -> Option<&EmbeddedTerminateCaptions>
pub fn terminate_captions(&self) -> Option<&EmbeddedTerminateCaptions>
By default, the service terminates any unterminated captions at the end of each input. If you want the caption to continue onto your next input, disable this setting.
Sourceimpl EmbeddedSourceSettings
impl EmbeddedSourceSettings
Sourcepub fn builder() -> EmbeddedSourceSettingsBuilder
pub fn builder() -> EmbeddedSourceSettingsBuilder
Creates a new builder-style object to manufacture EmbeddedSourceSettings.