#[non_exhaustive]pub struct EsamSignalProcessingNotification {
pub scc_xml: Option<String>,
}Expand description
ESAM SignalProcessingNotification data defined by OC-SP-ESAM-API-I03-131025.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.scc_xml: Option<String>Provide your ESAM SignalProcessingNotification XML document inside your JSON job settings. Form the XML document as per OC-SP-ESAM-API-I03-131025. The transcoder will use the signal processing instructions in the message that you supply. For your MPEG2-TS file outputs, if you want the service to place SCTE-35 markers at the insertion points you specify in the XML document, you must also enable SCTE-35 ESAM. Note that you can either specify an ESAM XML document or enable SCTE-35 passthrough. You can’t do both.
Implementations
Sourceimpl EsamSignalProcessingNotification
impl EsamSignalProcessingNotification
Sourcepub fn scc_xml(&self) -> Option<&str>
pub fn scc_xml(&self) -> Option<&str>
Provide your ESAM SignalProcessingNotification XML document inside your JSON job settings. Form the XML document as per OC-SP-ESAM-API-I03-131025. The transcoder will use the signal processing instructions in the message that you supply. For your MPEG2-TS file outputs, if you want the service to place SCTE-35 markers at the insertion points you specify in the XML document, you must also enable SCTE-35 ESAM. Note that you can either specify an ESAM XML document or enable SCTE-35 passthrough. You can’t do both.
Sourceimpl EsamSignalProcessingNotification
impl EsamSignalProcessingNotification
Sourcepub fn builder() -> EsamSignalProcessingNotificationBuilder
pub fn builder() -> EsamSignalProcessingNotificationBuilder
Creates a new builder-style object to manufacture EsamSignalProcessingNotification.