#[non_exhaustive]pub struct InputDecryptionSettings {
pub decryption_mode: Option<DecryptionMode>,
pub encrypted_decryption_key: Option<String>,
pub initialization_vector: Option<String>,
pub kms_key_region: Option<String>,
}Expand description
Settings for decrypting any input files that you encrypt before you upload them to Amazon S3. MediaConvert can decrypt files only when you use AWS Key Management Service (KMS) to encrypt the data key that you use to encrypt your content.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.decryption_mode: Option<DecryptionMode>Specify the encryption mode that you used to encrypt your input files.
encrypted_decryption_key: Option<String>Warning! Don’t provide your encryption key in plaintext. Your job settings could be intercepted, making your encrypted content vulnerable. Specify the encrypted version of the data key that you used to encrypt your content. The data key must be encrypted by AWS Key Management Service (KMS). The key can be 128, 192, or 256 bits.
initialization_vector: Option<String>Specify the initialization vector that you used when you encrypted your content before uploading it to Amazon S3. You can use a 16-byte initialization vector with any encryption mode. Or, you can use a 12-byte initialization vector with GCM or CTR. MediaConvert accepts only initialization vectors that are base64-encoded.
kms_key_region: Option<String>Specify the AWS Region for AWS Key Management Service (KMS) that you used to encrypt your data key, if that Region is different from the one you are using for AWS Elemental MediaConvert.
Implementations
Sourceimpl InputDecryptionSettings
impl InputDecryptionSettings
Sourcepub fn decryption_mode(&self) -> Option<&DecryptionMode>
pub fn decryption_mode(&self) -> Option<&DecryptionMode>
Specify the encryption mode that you used to encrypt your input files.
Sourcepub fn encrypted_decryption_key(&self) -> Option<&str>
pub fn encrypted_decryption_key(&self) -> Option<&str>
Warning! Don’t provide your encryption key in plaintext. Your job settings could be intercepted, making your encrypted content vulnerable. Specify the encrypted version of the data key that you used to encrypt your content. The data key must be encrypted by AWS Key Management Service (KMS). The key can be 128, 192, or 256 bits.
Sourcepub fn initialization_vector(&self) -> Option<&str>
pub fn initialization_vector(&self) -> Option<&str>
Specify the initialization vector that you used when you encrypted your content before uploading it to Amazon S3. You can use a 16-byte initialization vector with any encryption mode. Or, you can use a 12-byte initialization vector with GCM or CTR. MediaConvert accepts only initialization vectors that are base64-encoded.
Sourcepub fn kms_key_region(&self) -> Option<&str>
pub fn kms_key_region(&self) -> Option<&str>
Specify the AWS Region for AWS Key Management Service (KMS) that you used to encrypt your data key, if that Region is different from the one you are using for AWS Elemental MediaConvert.
Sourceimpl InputDecryptionSettings
impl InputDecryptionSettings
Sourcepub fn builder() -> InputDecryptionSettingsBuilder
pub fn builder() -> InputDecryptionSettingsBuilder
Creates a new builder-style object to manufacture InputDecryptionSettings.