InsertableImage

Struct InsertableImage 

#[non_exhaustive]
pub struct InsertableImage { pub duration: Option<i32>, pub fade_in: Option<i32>, pub fade_out: Option<i32>, pub height: Option<i32>, pub image_inserter_input: Option<String>, pub image_x: Option<i32>, pub image_y: Option<i32>, pub layer: Option<i32>, pub opacity: Option<i32>, pub start_time: Option<String>, pub width: Option<i32>, }
These settings apply to a specific graphic overlay. You can include multiple overlays in your job.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
duration: Option<i32>

Specify the time, in milliseconds, for the image to remain on the output video. This duration includes fade-in time but not fade-out time.

fade_in: Option<i32>

Specify the length of time, in milliseconds, between the Start time that you specify for the image insertion and the time that the image appears at full opacity. Full opacity is the level that you specify for the opacity setting. If you don’t specify a value for Fade-in, the image will appear abruptly at the overlay start time.

fade_out: Option<i32>

Specify the length of time, in milliseconds, between the end of the time that you have specified for the image overlay Duration and when the overlaid image has faded to total transparency. If you don’t specify a value for Fade-out, the image will disappear abruptly at the end of the inserted image duration.

height: Option<i32>

Specify the height of the inserted image in pixels. If you specify a value that’s larger than the video resolution height, the service will crop your overlaid image to fit. To use the native height of the image, keep this setting blank.

image_inserter_input: Option<String>

Specify the HTTP, HTTPS, or Amazon S3 location of the image that you want to overlay on the video. Use a PNG or TGA file.

image_x: Option<i32>

Specify the distance, in pixels, between the inserted image and the left edge of the video frame. Required for any image overlay that you specify.

image_y: Option<i32>

Specify the distance, in pixels, between the overlaid image and the top edge of the video frame. Required for any image overlay that you specify.

layer: Option<i32>

Specify how overlapping inserted images appear. Images with higher values for Layer appear on top of images with lower values for Layer.

opacity: Option<i32>

Use Opacity to specify how much of the underlying video shows through the inserted image. 0 is transparent and 100 is fully opaque. Default is 50.

start_time: Option<String>

Specify the timecode of the frame that you want the overlay to first appear on. This must be in timecode (HH:MM:SS:FF or HH:MM:SS;FF) format. Remember to take into account your timecode source settings.

width: Option<i32>

Specify the width of the inserted image in pixels. If you specify a value that’s larger than the video resolution width, the service will crop your overlaid image to fit. To use the native width of the image, keep this setting blank.

Implementations

Source

impl InsertableImage

pub fn duration(&self) -> Option<i32>

Specify the time, in milliseconds, for the image to remain on the output video. This duration includes fade-in time but not fade-out time.

pub fn fade_in(&self) -> Option<i32>

Specify the length of time, in milliseconds, between the Start time that you specify for the image insertion and the time that the image appears at full opacity. Full opacity is the level that you specify for the opacity setting. If you don’t specify a value for Fade-in, the image will appear abruptly at the overlay start time.

pub fn fade_out(&self) -> Option<i32>

Specify the length of time, in milliseconds, between the end of the time that you have specified for the image overlay Duration and when the overlaid image has faded to total transparency. If you don’t specify a value for Fade-out, the image will disappear abruptly at the end of the inserted image duration.

pub fn height(&self) -> Option<i32>

Specify the height of the inserted image in pixels. If you specify a value that’s larger than the video resolution height, the service will crop your overlaid image to fit. To use the native height of the image, keep this setting blank.

pub fn image_inserter_input(&self) -> Option<&str>

Specify the HTTP, HTTPS, or Amazon S3 location of the image that you want to overlay on the video. Use a PNG or TGA file.

pub fn image_x(&self) -> Option<i32>

Specify the distance, in pixels, between the inserted image and the left edge of the video frame. Required for any image overlay that you specify.

pub fn image_y(&self) -> Option<i32>

Specify the distance, in pixels, between the overlaid image and the top edge of the video frame. Required for any image overlay that you specify.

pub fn layer(&self) -> Option<i32>

Specify how overlapping inserted images appear. Images with higher values for Layer appear on top of images with lower values for Layer.

pub fn opacity(&self) -> Option<i32>

Use Opacity to specify how much of the underlying video shows through the inserted image. 0 is transparent and 100 is fully opaque. Default is 50.

pub fn start_time(&self) -> Option<&str>

Specify the timecode of the frame that you want the overlay to first appear on. This must be in timecode (HH:MM:SS:FF or HH:MM:SS;FF) format. Remember to take into account your timecode source settings.

pub fn width(&self) -> Option<i32>

Specify the width of the inserted image in pixels. If you specify a value that’s larger than the video resolution width, the service will crop your overlaid image to fit. To use the native width of the image, keep this setting blank.

Source

impl InsertableImage

pub fn builder() -> InsertableImageBuilder

Creates a new builder-style object to manufacture InsertableImage.