JobEngineVersion

Struct JobEngineVersion 

#[non_exhaustive]
pub struct JobEngineVersion { pub expiration_date: Option<DateTime>, pub version: Option<String>, }
Use Job engine versions to run jobs for your production workflow on one version, while you test and validate the latest version. Job engine versions are in a YYYY-MM-DD format.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
expiration_date: Option<DateTime>

The date that this Job engine version expires. Requests to create jobs with an expired version result in a regular job, as if no specific Job engine version was requested.

version: Option<String>

Use Job engine versions to run jobs for your production workflow on one version, while you test and validate the latest version. Job engine versions represent periodically grouped MediaConvert releases with new features, updates, improvements, and fixes. Job engine versions are in a YYYY-MM-DD format. Note that the Job engine version feature is not publicly available at this time. To request access, contact AWS support.

Implementations

Source

impl JobEngineVersion

pub fn expiration_date(&self) -> Option<&DateTime>

The date that this Job engine version expires. Requests to create jobs with an expired version result in a regular job, as if no specific Job engine version was requested.

pub fn version(&self) -> Option<&str>

Use Job engine versions to run jobs for your production workflow on one version, while you test and validate the latest version. Job engine versions represent periodically grouped MediaConvert releases with new features, updates, improvements, and fixes. Job engine versions are in a YYYY-MM-DD format. Note that the Job engine version feature is not publicly available at this time. To request access, contact AWS support.

Source

impl JobEngineVersion

pub fn builder() -> JobEngineVersionBuilder

Creates a new builder-style object to manufacture JobEngineVersion.