#[non_exhaustive]pub struct OutputChannelMapping {
pub input_channels: Option<Vec<i32>>,
pub input_channels_fine_tune: Option<Vec<f64>>,
}Expand description
OutputChannel mapping settings.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.input_channels: Option<Vec<i32>>Use this setting to specify your remix values when they are integers, such as -10, 0, or 4.
input_channels_fine_tune: Option<Vec<f64>>Use this setting to specify your remix values when they have a decimal component, such as -10.312, 0.08, or 4.9. MediaConvert rounds your remixing values to the nearest thousandth.
Implementations
Sourceimpl OutputChannelMapping
impl OutputChannelMapping
Sourcepub fn input_channels(&self) -> &[i32]
pub fn input_channels(&self) -> &[i32]
Use this setting to specify your remix values when they are integers, such as -10, 0, or 4.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .input_channels.is_none().
Sourcepub fn input_channels_fine_tune(&self) -> &[f64]
pub fn input_channels_fine_tune(&self) -> &[f64]
Use this setting to specify your remix values when they have a decimal component, such as -10.312, 0.08, or 4.9. MediaConvert rounds your remixing values to the nearest thousandth.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .input_channels_fine_tune.is_none().
Sourceimpl OutputChannelMapping
impl OutputChannelMapping
Sourcepub fn builder() -> OutputChannelMappingBuilder
pub fn builder() -> OutputChannelMappingBuilder
Creates a new builder-style object to manufacture OutputChannelMapping.