#[non_exhaustive]pub struct QueueTransition {
pub destination_queue: Option<String>,
pub source_queue: Option<String>,
pub timestamp: Option<DateTime>,
}Expand description
Description of the source and destination queues between which the job has moved, along with the timestamp of the move
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.destination_queue: Option<String>The queue that the job was on after the transition.
source_queue: Option<String>The queue that the job was on before the transition.
timestamp: Option<DateTime>The time, in Unix epoch format, that the job moved from the source queue to the destination queue.
Implementations
Sourceimpl QueueTransition
impl QueueTransition
Sourcepub fn destination_queue(&self) -> Option<&str>
pub fn destination_queue(&self) -> Option<&str>
The queue that the job was on after the transition.
Sourcepub fn source_queue(&self) -> Option<&str>
pub fn source_queue(&self) -> Option<&str>
The queue that the job was on before the transition.
Sourceimpl QueueTransition
impl QueueTransition
Sourcepub fn builder() -> QueueTransitionBuilder
pub fn builder() -> QueueTransitionBuilder
Creates a new builder-style object to manufacture QueueTransition.