#[non_exhaustive]pub struct StaticKeyProvider {
pub key_format: Option<String>,
pub key_format_versions: Option<String>,
pub static_key_value: Option<String>,
pub url: Option<String>,
}Expand description
Use these settings to set up encryption with a static key provider.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.key_format: Option<String>Relates to DRM implementation. Sets the value of the KEYFORMAT attribute. Must be ‘identity’ or a reverse DNS string. May be omitted to indicate an implicit value of ‘identity’.
key_format_versions: Option<String>Relates to DRM implementation. Either a single positive integer version value or a slash delimited list of version values (1/2/3).
static_key_value: Option<String>Relates to DRM implementation. Use a 32-character hexidecimal string to specify Key Value.
url: Option<String>Relates to DRM implementation. The location of the license server used for protecting content.
Implementations
Sourceimpl StaticKeyProvider
impl StaticKeyProvider
Sourcepub fn key_format(&self) -> Option<&str>
pub fn key_format(&self) -> Option<&str>
Relates to DRM implementation. Sets the value of the KEYFORMAT attribute. Must be ‘identity’ or a reverse DNS string. May be omitted to indicate an implicit value of ‘identity’.
Sourcepub fn key_format_versions(&self) -> Option<&str>
pub fn key_format_versions(&self) -> Option<&str>
Relates to DRM implementation. Either a single positive integer version value or a slash delimited list of version values (1/2/3).
Sourcepub fn static_key_value(&self) -> Option<&str>
pub fn static_key_value(&self) -> Option<&str>
Relates to DRM implementation. Use a 32-character hexidecimal string to specify Key Value.
Sourceimpl StaticKeyProvider
impl StaticKeyProvider
Sourcepub fn builder() -> StaticKeyProviderBuilder
pub fn builder() -> StaticKeyProviderBuilder
Creates a new builder-style object to manufacture StaticKeyProvider.