#[non_exhaustive]pub struct TimecodeBurnin {
pub font_size: Option<i32>,
pub position: Option<TimecodeBurninPosition>,
pub prefix: Option<String>,
}Expand description
Settings for burning the output timecode and specified prefix into the output.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.font_size: Option<i32>Use Font size to set the font size of any burned-in timecode. Valid values are 10, 16, 32, 48.
position: Option<TimecodeBurninPosition>Use Position under Timecode burn-in to specify the location the burned-in timecode on output video.
prefix: Option<String>Use Prefix to place ASCII characters before any burned-in timecode. For example, a prefix of “EZ-” will result in the timecode “EZ-00:00:00:00”. Provide either the characters themselves or the ASCII code equivalents. The supported range of characters is 0x20 through 0x7e. This includes letters, numbers, and all special characters represented on a standard English keyboard.
Implementations
Sourceimpl TimecodeBurnin
impl TimecodeBurnin
Sourcepub fn font_size(&self) -> Option<i32>
pub fn font_size(&self) -> Option<i32>
Use Font size to set the font size of any burned-in timecode. Valid values are 10, 16, 32, 48.
Sourcepub fn position(&self) -> Option<&TimecodeBurninPosition>
pub fn position(&self) -> Option<&TimecodeBurninPosition>
Use Position under Timecode burn-in to specify the location the burned-in timecode on output video.
Sourcepub fn prefix(&self) -> Option<&str>
pub fn prefix(&self) -> Option<&str>
Use Prefix to place ASCII characters before any burned-in timecode. For example, a prefix of “EZ-” will result in the timecode “EZ-00:00:00:00”. Provide either the characters themselves or the ASCII code equivalents. The supported range of characters is 0x20 through 0x7e. This includes letters, numbers, and all special characters represented on a standard English keyboard.
Sourceimpl TimecodeBurnin
impl TimecodeBurnin
Sourcepub fn builder() -> TimecodeBurninBuilder
pub fn builder() -> TimecodeBurninBuilder
Creates a new builder-style object to manufacture TimecodeBurnin.