#[non_exhaustive]pub struct TimedMetadataInsertion {
pub id3_insertions: Option<Vec<Id3Insertion>>,
}Expand description
Insert user-defined custom ID3 metadata at timecodes that you specify. In each output that you want to include this metadata, you must set ID3 metadata to Passthrough.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id3_insertions: Option<Vec<Id3Insertion>>Id3Insertions contains the array of Id3Insertion instances.
Implementations
Sourceimpl TimedMetadataInsertion
impl TimedMetadataInsertion
Sourcepub fn id3_insertions(&self) -> &[Id3Insertion]
pub fn id3_insertions(&self) -> &[Id3Insertion]
Id3Insertions contains the array of Id3Insertion instances.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .id3_insertions.is_none().
Sourceimpl TimedMetadataInsertion
impl TimedMetadataInsertion
Sourcepub fn builder() -> TimedMetadataInsertionBuilder
pub fn builder() -> TimedMetadataInsertionBuilder
Creates a new builder-style object to manufacture TimedMetadataInsertion.