#[non_exhaustive]pub struct TrackMapping {
pub audio_track_indexes: Option<Vec<i32>>,
pub data_track_indexes: Option<Vec<i32>>,
pub video_track_indexes: Option<Vec<i32>>,
}Expand description
An array containing track mapping information.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.audio_track_indexes: Option<Vec<i32>>The index numbers of the audio tracks in your media file.
data_track_indexes: Option<Vec<i32>>The index numbers of the data tracks in your media file.
video_track_indexes: Option<Vec<i32>>The index numbers of the video tracks in your media file.
Implementations
Sourceimpl TrackMapping
impl TrackMapping
Sourcepub fn audio_track_indexes(&self) -> &[i32]
pub fn audio_track_indexes(&self) -> &[i32]
The index numbers of the audio tracks in your media file.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .audio_track_indexes.is_none().
Sourcepub fn data_track_indexes(&self) -> &[i32]
pub fn data_track_indexes(&self) -> &[i32]
The index numbers of the data tracks in your media file.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .data_track_indexes.is_none().
Sourcepub fn video_track_indexes(&self) -> &[i32]
pub fn video_track_indexes(&self) -> &[i32]
The index numbers of the video tracks in your media file.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .video_track_indexes.is_none().
Sourceimpl TrackMapping
impl TrackMapping
Sourcepub fn builder() -> TrackMappingBuilder
pub fn builder() -> TrackMappingBuilder
Creates a new builder-style object to manufacture TrackMapping.