VideoDescription

Struct VideoDescription 

#[non_exhaustive]
pub struct VideoDescription {
Show 17 fields pub afd_signaling: Option<AfdSignaling>, pub anti_alias: Option<AntiAlias>, pub chroma_position_mode: Option<ChromaPositionMode>, pub codec_settings: Option<VideoCodecSettings>, pub color_metadata: Option<ColorMetadata>, pub crop: Option<Rectangle>, pub drop_frame_timecode: Option<DropFrameTimecode>, pub fixed_afd: Option<i32>, pub height: Option<i32>, pub position: Option<Rectangle>, pub respond_to_afd: Option<RespondToAfd>, pub scaling_behavior: Option<ScalingBehavior>, pub sharpness: Option<i32>, pub timecode_insertion: Option<VideoTimecodeInsertion>, pub timecode_track: Option<TimecodeTrack>, pub video_preprocessors: Option<VideoPreprocessor>, pub width: Option<i32>,
}
Settings related to video encoding of your output. The specific video settings depend on the video codec that you choose.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
afd_signaling: Option<AfdSignaling>

This setting only applies to H.264, H.265, and MPEG2 outputs. Use Insert AFD signaling to specify whether the service includes AFD values in the output video data and what those values are. * Choose None to remove all AFD values from this output. * Choose Fixed to ignore input AFD values and instead encode the value specified in the job. * Choose Auto to calculate output AFD values based on the input AFD scaler data.

anti_alias: Option<AntiAlias>

The anti-alias filter is automatically applied to all outputs. The service no longer accepts the value DISABLED for AntiAlias. If you specify that in your job, the service will ignore the setting.

chroma_position_mode: Option<ChromaPositionMode>

Specify the chroma sample positioning metadata for your H.264 or H.265 output. To have MediaConvert automatically determine chroma positioning: We recommend that you keep the default value, Auto. To specify center positioning: Choose Force center. To specify top left positioning: Choose Force top left.

codec_settings: Option<VideoCodecSettings>

Video codec settings contains the group of settings related to video encoding. The settings in this group vary depending on the value that you choose for Video codec. For each codec enum that you choose, define the corresponding settings object. The following lists the codec enum, settings object pairs. * AV1, Av1Settings * AVC_INTRA, AvcIntraSettings * FRAME_CAPTURE, FrameCaptureSettings * GIF, GifSettings * H_264, H264Settings * H_265, H265Settings * MPEG2, Mpeg2Settings * PRORES, ProresSettings * UNCOMPRESSED, UncompressedSettings * VC3, Vc3Settings * VP8, Vp8Settings * VP9, Vp9Settings * XAVC, XavcSettings

color_metadata: Option<ColorMetadata>

Choose Insert for this setting to include color metadata in this output. Choose Ignore to exclude color metadata from this output. If you don’t specify a value, the service sets this to Insert by default.

crop: Option<Rectangle>

Use Cropping selection to specify the video area that the service will include in the output video frame.

drop_frame_timecode: Option<DropFrameTimecode>

Applies only to 29.97 fps outputs. When this feature is enabled, the service will use drop-frame timecode on outputs. If it is not possible to use drop-frame timecode, the system will fall back to non-drop-frame. This setting is enabled by default when Timecode insertion or Timecode track is enabled.

fixed_afd: Option<i32>

Applies only if you set AFD Signaling to Fixed. Use Fixed to specify a four-bit AFD value which the service will write on all frames of this video output.

height: Option<i32>

Use Height to define the video resolution height, in pixels, for this output. To use the same resolution as your input: Leave both Width and Height blank. To evenly scale from your input resolution: Leave Height blank and enter a value for Width. For example, if your input is 1920x1080 and you set Width to 1280, your output will be 1280x720.

position: Option<Rectangle>

Use Selection placement to define the video area in your output frame. The area outside of the rectangle that you specify here is black.

respond_to_afd: Option<RespondToAfd>

Use Respond to AFD to specify how the service changes the video itself in response to AFD values in the input. * Choose Respond to clip the input video frame according to the AFD value, input display aspect ratio, and output display aspect ratio. * Choose Passthrough to include the input AFD values. Do not choose this when AfdSignaling is set to NONE. A preferred implementation of this workflow is to set RespondToAfd to and set AfdSignaling to AUTO. * Choose None to remove all input AFD values from this output.

scaling_behavior: Option<ScalingBehavior>

Specify the video Scaling behavior when your output has a different resolution than your input. For more information, see https://docs.aws.amazon.com/mediaconvert/latest/ug/video-scaling.html Select Smart Cropping using Elemental Inference as your scaling behavior to have Elemental Inference automatically crop your video. Smart Crop requires a vertical output aspect ratio (1:1 is the widest aspect ratio supported).

sharpness: Option<i32>

Use Sharpness setting to specify the strength of anti-aliasing. This setting changes the width of the anti-alias filter kernel used for scaling. Sharpness only applies if your output resolution is different from your input resolution. 0 is the softest setting, 100 the sharpest, and 50 recommended for most content.

timecode_insertion: Option<VideoTimecodeInsertion>

Applies only to H.264, H.265, MPEG2, and ProRes outputs. Only enable Timecode insertion when the input frame rate is identical to the output frame rate. To include timecodes in this output, set Timecode insertion to PIC_TIMING_SEI. To leave them out, set it to DISABLED. Default is DISABLED. When the service inserts timecodes in an output, by default, it uses any embedded timecodes from the input. If none are present, the service will set the timecode for the first output frame to zero. To change this default behavior, adjust the settings under Timecode configuration. In the console, these settings are located under Job > Job settings > Timecode configuration. Note - Timecode source under input settings does not affect the timecodes that are inserted in the output. Source under Job settings > Timecode configuration does.

timecode_track: Option<TimecodeTrack>

To include a timecode track in your MP4 output: Choose Enabled. MediaConvert writes the timecode track in the Null Media Header box (NMHD), without any timecode text formatting information. You can also specify dropframe or non-dropframe timecode under the Drop Frame Timecode setting. To not include a timecode track: Keep the default value, Disabled.

video_preprocessors: Option<VideoPreprocessor>

Find additional transcoding features under Preprocessors. Enable the features at each output individually. These features are disabled by default.

width: Option<i32>

Use Width to define the video resolution width, in pixels, for this output. To use the same resolution as your input: Leave both Width and Height blank. To evenly scale from your input resolution: Leave Width blank and enter a value for Height. For example, if your input is 1920x1080 and you set Height to 720, your output will be 1280x720.

Implementations

Source

impl VideoDescription

pub fn afd_signaling(&self) -> Option<&AfdSignaling>

This setting only applies to H.264, H.265, and MPEG2 outputs. Use Insert AFD signaling to specify whether the service includes AFD values in the output video data and what those values are. * Choose None to remove all AFD values from this output. * Choose Fixed to ignore input AFD values and instead encode the value specified in the job. * Choose Auto to calculate output AFD values based on the input AFD scaler data.

pub fn anti_alias(&self) -> Option<&AntiAlias>

The anti-alias filter is automatically applied to all outputs. The service no longer accepts the value DISABLED for AntiAlias. If you specify that in your job, the service will ignore the setting.

pub fn chroma_position_mode(&self) -> Option<&ChromaPositionMode>

Specify the chroma sample positioning metadata for your H.264 or H.265 output. To have MediaConvert automatically determine chroma positioning: We recommend that you keep the default value, Auto. To specify center positioning: Choose Force center. To specify top left positioning: Choose Force top left.

pub fn codec_settings(&self) -> Option<&VideoCodecSettings>

Video codec settings contains the group of settings related to video encoding. The settings in this group vary depending on the value that you choose for Video codec. For each codec enum that you choose, define the corresponding settings object. The following lists the codec enum, settings object pairs. * AV1, Av1Settings * AVC_INTRA, AvcIntraSettings * FRAME_CAPTURE, FrameCaptureSettings * GIF, GifSettings * H_264, H264Settings * H_265, H265Settings * MPEG2, Mpeg2Settings * PRORES, ProresSettings * UNCOMPRESSED, UncompressedSettings * VC3, Vc3Settings * VP8, Vp8Settings * VP9, Vp9Settings * XAVC, XavcSettings

pub fn color_metadata(&self) -> Option<&ColorMetadata>

Choose Insert for this setting to include color metadata in this output. Choose Ignore to exclude color metadata from this output. If you don’t specify a value, the service sets this to Insert by default.

pub fn crop(&self) -> Option<&Rectangle>

Use Cropping selection to specify the video area that the service will include in the output video frame.

pub fn drop_frame_timecode(&self) -> Option<&DropFrameTimecode>

Applies only to 29.97 fps outputs. When this feature is enabled, the service will use drop-frame timecode on outputs. If it is not possible to use drop-frame timecode, the system will fall back to non-drop-frame. This setting is enabled by default when Timecode insertion or Timecode track is enabled.

pub fn fixed_afd(&self) -> Option<i32>

Applies only if you set AFD Signaling to Fixed. Use Fixed to specify a four-bit AFD value which the service will write on all frames of this video output.

pub fn height(&self) -> Option<i32>

Use Height to define the video resolution height, in pixels, for this output. To use the same resolution as your input: Leave both Width and Height blank. To evenly scale from your input resolution: Leave Height blank and enter a value for Width. For example, if your input is 1920x1080 and you set Width to 1280, your output will be 1280x720.

pub fn position(&self) -> Option<&Rectangle>

Use Selection placement to define the video area in your output frame. The area outside of the rectangle that you specify here is black.

pub fn respond_to_afd(&self) -> Option<&RespondToAfd>

Use Respond to AFD to specify how the service changes the video itself in response to AFD values in the input. * Choose Respond to clip the input video frame according to the AFD value, input display aspect ratio, and output display aspect ratio. * Choose Passthrough to include the input AFD values. Do not choose this when AfdSignaling is set to NONE. A preferred implementation of this workflow is to set RespondToAfd to and set AfdSignaling to AUTO. * Choose None to remove all input AFD values from this output.

pub fn scaling_behavior(&self) -> Option<&ScalingBehavior>

Specify the video Scaling behavior when your output has a different resolution than your input. For more information, see https://docs.aws.amazon.com/mediaconvert/latest/ug/video-scaling.html Select Smart Cropping using Elemental Inference as your scaling behavior to have Elemental Inference automatically crop your video. Smart Crop requires a vertical output aspect ratio (1:1 is the widest aspect ratio supported).

pub fn sharpness(&self) -> Option<i32>

Use Sharpness setting to specify the strength of anti-aliasing. This setting changes the width of the anti-alias filter kernel used for scaling. Sharpness only applies if your output resolution is different from your input resolution. 0 is the softest setting, 100 the sharpest, and 50 recommended for most content.

pub fn timecode_insertion(&self) -> Option<&VideoTimecodeInsertion>

Applies only to H.264, H.265, MPEG2, and ProRes outputs. Only enable Timecode insertion when the input frame rate is identical to the output frame rate. To include timecodes in this output, set Timecode insertion to PIC_TIMING_SEI. To leave them out, set it to DISABLED. Default is DISABLED. When the service inserts timecodes in an output, by default, it uses any embedded timecodes from the input. If none are present, the service will set the timecode for the first output frame to zero. To change this default behavior, adjust the settings under Timecode configuration. In the console, these settings are located under Job > Job settings > Timecode configuration. Note - Timecode source under input settings does not affect the timecodes that are inserted in the output. Source under Job settings > Timecode configuration does.

pub fn timecode_track(&self) -> Option<&TimecodeTrack>

To include a timecode track in your MP4 output: Choose Enabled. MediaConvert writes the timecode track in the Null Media Header box (NMHD), without any timecode text formatting information. You can also specify dropframe or non-dropframe timecode under the Drop Frame Timecode setting. To not include a timecode track: Keep the default value, Disabled.

pub fn video_preprocessors(&self) -> Option<&VideoPreprocessor>

Find additional transcoding features under Preprocessors. Enable the features at each output individually. These features are disabled by default.

pub fn width(&self) -> Option<i32>

Use Width to define the video resolution width, in pixels, for this output. To use the same resolution as your input: Leave both Width and Height blank. To evenly scale from your input resolution: Leave Width blank and enter a value for Height. For example, if your input is 1920x1080 and you set Height to 720, your output will be 1280x720.

Source

impl VideoDescription

pub fn builder() -> VideoDescriptionBuilder

Creates a new builder-style object to manufacture VideoDescription.