#[non_exhaustive]pub struct VideoOverlayInput {
pub audio_selectors: Option<HashMap<String, AudioSelector>>,
pub file_input: Option<String>,
pub input_clippings: Option<Vec<VideoOverlayInputClipping>>,
pub timecode_source: Option<InputTimecodeSource>,
pub timecode_start: Option<String>,
}Expand description
Input settings for Video overlay. You can include one or more video overlays in sequence at different times that you specify.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.audio_selectors: Option<HashMap<String, AudioSelector>>Use Audio selectors to specify audio to use during your Video overlay. You can use multiple Audio selectors per Video overlay. When you include an Audio selector within a Video overlay, MediaConvert mutes any Audio selectors with the same name from the underlying input. For example, if your underlying input has Audio selector 1 and Audio selector 2, and your Video overlay only has Audio selector 1, then MediaConvert replaces all audio for Audio selector 1 during the Video overlay. To replace all audio for all Audio selectors from the underlying input by using a single Audio selector in your overlay, set DefaultSelection to DEFAULT (Check "Use as default" in the MediaConvert console).
file_input: Option<String>Specify the input file S3, HTTP, or HTTPS URL for your video overlay. To specify one or more Transitions for your base input video instead: Leave blank.
input_clippings: Option<Vec<VideoOverlayInputClipping>>Specify one or more clips to use from your video overlay. When you include an input clip, you must also specify its start timecode, end timecode, or both start and end timecode.
timecode_source: Option<InputTimecodeSource>Specify the timecode source for your video overlay input clips. To use the timecode present in your video overlay: Choose Embedded. To use a zerobased timecode: Choose Start at 0. To choose a timecode: Choose Specified start. When you do, enter the starting timecode in Start timecode. If you don’t specify a value for Timecode source, MediaConvert uses Embedded by default.
timecode_start: Option<String>Specify the starting timecode for this video overlay. To use this setting, you must set Timecode source to Specified start.
Implementations
Sourceimpl VideoOverlayInput
impl VideoOverlayInput
Sourcepub fn audio_selectors(&self) -> Option<&HashMap<String, AudioSelector>>
pub fn audio_selectors(&self) -> Option<&HashMap<String, AudioSelector>>
Use Audio selectors to specify audio to use during your Video overlay. You can use multiple Audio selectors per Video overlay. When you include an Audio selector within a Video overlay, MediaConvert mutes any Audio selectors with the same name from the underlying input. For example, if your underlying input has Audio selector 1 and Audio selector 2, and your Video overlay only has Audio selector 1, then MediaConvert replaces all audio for Audio selector 1 during the Video overlay. To replace all audio for all Audio selectors from the underlying input by using a single Audio selector in your overlay, set DefaultSelection to DEFAULT (Check "Use as default" in the MediaConvert console).
Sourcepub fn file_input(&self) -> Option<&str>
pub fn file_input(&self) -> Option<&str>
Specify the input file S3, HTTP, or HTTPS URL for your video overlay. To specify one or more Transitions for your base input video instead: Leave blank.
Sourcepub fn input_clippings(&self) -> &[VideoOverlayInputClipping]
pub fn input_clippings(&self) -> &[VideoOverlayInputClipping]
Specify one or more clips to use from your video overlay. When you include an input clip, you must also specify its start timecode, end timecode, or both start and end timecode.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .input_clippings.is_none().
Sourcepub fn timecode_source(&self) -> Option<&InputTimecodeSource>
pub fn timecode_source(&self) -> Option<&InputTimecodeSource>
Specify the timecode source for your video overlay input clips. To use the timecode present in your video overlay: Choose Embedded. To use a zerobased timecode: Choose Start at 0. To choose a timecode: Choose Specified start. When you do, enter the starting timecode in Start timecode. If you don’t specify a value for Timecode source, MediaConvert uses Embedded by default.
Sourcepub fn timecode_start(&self) -> Option<&str>
pub fn timecode_start(&self) -> Option<&str>
Specify the starting timecode for this video overlay. To use this setting, you must set Timecode source to Specified start.
Sourceimpl VideoOverlayInput
impl VideoOverlayInput
Sourcepub fn builder() -> VideoOverlayInputBuilder
pub fn builder() -> VideoOverlayInputBuilder
Creates a new builder-style object to manufacture VideoOverlayInput.