VideoPreprocessor

Struct VideoPreprocessor 

#[non_exhaustive]
pub struct VideoPreprocessor { pub color_corrector: Option<ColorCorrector>, pub deinterlacer: Option<Deinterlacer>, pub dolby_vision: Option<DolbyVision>, pub hdr10_plus: Option<Hdr10Plus>, pub image_inserter: Option<ImageInserter>, pub noise_reducer: Option<NoiseReducer>, pub partner_watermarking: Option<PartnerWatermarking>, pub timecode_burnin: Option<TimecodeBurnin>, }
Find additional transcoding features under Preprocessors. Enable the features at each output individually. These features are disabled by default.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
color_corrector: Option<ColorCorrector>

Use these settings to convert the color space or to modify properties such as hue and contrast for this output. For more information, see https://docs.aws.amazon.com/mediaconvert/latest/ug/converting-the-color-space.html.

deinterlacer: Option<Deinterlacer>

Use the deinterlacer to produce smoother motion and a clearer picture. For more information, see https://docs.aws.amazon.com/mediaconvert/latest/ug/working-with-scan-type.html.

dolby_vision: Option<DolbyVision>

Enable Dolby Vision feature to produce Dolby Vision compatible video output.

hdr10_plus: Option<Hdr10Plus>

Enable HDR10+ analysis and metadata injection. Compatible with HEVC only.

image_inserter: Option<ImageInserter>

Enable the Image inserter feature to include a graphic overlay on your video. Enable or disable this feature for each output individually. This setting is disabled by default.

noise_reducer: Option<NoiseReducer>

Enable the Noise reducer feature to remove noise from your video output if necessary. Enable or disable this feature for each output individually. This setting is disabled by default. When you enable Noise reducer, you must also select a value for Noise reducer filter. For AVC outputs, when you include Noise reducer, you cannot include the Bandwidth reduction filter.

partner_watermarking: Option<PartnerWatermarking>

If you work with a third party video watermarking partner, use the group of settings that correspond with your watermarking partner to include watermarks in your output.

timecode_burnin: Option<TimecodeBurnin>

Settings for burning the output timecode and specified prefix into the output.

Implementations

Source

impl VideoPreprocessor

pub fn color_corrector(&self) -> Option<&ColorCorrector>

Use these settings to convert the color space or to modify properties such as hue and contrast for this output. For more information, see https://docs.aws.amazon.com/mediaconvert/latest/ug/converting-the-color-space.html.

pub fn deinterlacer(&self) -> Option<&Deinterlacer>

Use the deinterlacer to produce smoother motion and a clearer picture. For more information, see https://docs.aws.amazon.com/mediaconvert/latest/ug/working-with-scan-type.html.

pub fn dolby_vision(&self) -> Option<&DolbyVision>

Enable Dolby Vision feature to produce Dolby Vision compatible video output.

pub fn hdr10_plus(&self) -> Option<&Hdr10Plus>

Enable HDR10+ analysis and metadata injection. Compatible with HEVC only.

pub fn image_inserter(&self) -> Option<&ImageInserter>

Enable the Image inserter feature to include a graphic overlay on your video. Enable or disable this feature for each output individually. This setting is disabled by default.

pub fn noise_reducer(&self) -> Option<&NoiseReducer>

Enable the Noise reducer feature to remove noise from your video output if necessary. Enable or disable this feature for each output individually. This setting is disabled by default. When you enable Noise reducer, you must also select a value for Noise reducer filter. For AVC outputs, when you include Noise reducer, you cannot include the Bandwidth reduction filter.

pub fn partner_watermarking(&self) -> Option<&PartnerWatermarking>

If you work with a third party video watermarking partner, use the group of settings that correspond with your watermarking partner to include watermarks in your output.

pub fn timecode_burnin(&self) -> Option<&TimecodeBurnin>

Settings for burning the output timecode and specified prefix into the output.

Source

impl VideoPreprocessor

pub fn builder() -> VideoPreprocessorBuilder

Creates a new builder-style object to manufacture VideoPreprocessor.