#[non_exhaustive]pub struct CreateQueueInput {
pub concurrent_jobs: Option<i32>,
pub description: Option<String>,
pub maximum_concurrent_feeds: Option<i32>,
pub name: Option<String>,
pub pricing_plan: Option<PricingPlan>,
pub reservation_plan_settings: Option<ReservationPlanSettings>,
pub status: Option<QueueStatus>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.concurrent_jobs: Option<i32>Specify the maximum number of jobs your queue can process concurrently. For on-demand queues, the value you enter is constrained by your service quotas for Maximum concurrent jobs, per on-demand queue and Maximum concurrent jobs, per account. For reserved queues, specify the number of jobs you can process concurrently in your reservation plan instead.
description: Option<String>Optional. A description of the queue that you are creating.
maximum_concurrent_feeds: Option<i32>Specify the maximum number of Elemental Inference feeds MediaConvert can process concurrently.
name: Option<String>The name of the queue that you are creating.
pricing_plan: Option<PricingPlan>Specifies whether the pricing plan for the queue is on-demand or reserved. For on-demand, you pay per minute, billed in increments of .01 minute. For reserved, you pay for the transcoding capacity of the entire queue, regardless of how much or how little you use it. Reserved pricing requires a 12-month commitment. When you use the API to create a queue, the default is on-demand.
reservation_plan_settings: Option<ReservationPlanSettings>Details about the pricing plan for your reserved queue. Required for reserved queues and not applicable to on-demand queues.
status: Option<QueueStatus>Initial state of the queue. If you create a paused queue, then jobs in that queue won’t begin.
The tags that you want to add to the resource. You can tag resources with a key-value pair or with only a key.
Implementations
Sourceimpl CreateQueueInput
impl CreateQueueInput
Sourcepub fn concurrent_jobs(&self) -> Option<i32>
pub fn concurrent_jobs(&self) -> Option<i32>
Specify the maximum number of jobs your queue can process concurrently. For on-demand queues, the value you enter is constrained by your service quotas for Maximum concurrent jobs, per on-demand queue and Maximum concurrent jobs, per account. For reserved queues, specify the number of jobs you can process concurrently in your reservation plan instead.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
Optional. A description of the queue that you are creating.
Sourcepub fn maximum_concurrent_feeds(&self) -> Option<i32>
pub fn maximum_concurrent_feeds(&self) -> Option<i32>
Specify the maximum number of Elemental Inference feeds MediaConvert can process concurrently.
Sourcepub fn pricing_plan(&self) -> Option<&PricingPlan>
pub fn pricing_plan(&self) -> Option<&PricingPlan>
Specifies whether the pricing plan for the queue is on-demand or reserved. For on-demand, you pay per minute, billed in increments of .01 minute. For reserved, you pay for the transcoding capacity of the entire queue, regardless of how much or how little you use it. Reserved pricing requires a 12-month commitment. When you use the API to create a queue, the default is on-demand.
Sourcepub fn reservation_plan_settings(&self) -> Option<&ReservationPlanSettings>
pub fn reservation_plan_settings(&self) -> Option<&ReservationPlanSettings>
Details about the pricing plan for your reserved queue. Required for reserved queues and not applicable to on-demand queues.
Sourcepub fn status(&self) -> Option<&QueueStatus>
pub fn status(&self) -> Option<&QueueStatus>
Initial state of the queue. If you create a paused queue, then jobs in that queue won’t begin.
The tags that you want to add to the resource. You can tag resources with a key-value pair or with only a key.
Sourceimpl CreateQueueInput
impl CreateQueueInput
Sourcepub fn builder() -> CreateQueueInputBuilder
pub fn builder() -> CreateQueueInputBuilder
Creates a new builder-style object to manufacture CreateQueueInput.