pub struct UpdateQueueFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateQueue.
Modify one of your existing queues.
Implementations
Sourceimpl UpdateQueueFluentBuilder
impl UpdateQueueFluentBuilder
Sourcepub fn as_input(&self) -> &UpdateQueueInputBuilder
pub fn as_input(&self) -> &UpdateQueueInputBuilder
Access the UpdateQueue as a reference.
Sourcepub async fn send(
self,
) -> Result<UpdateQueueOutput, SdkError<UpdateQueueError, HttpResponse>>
pub async fn send( self, ) -> Result<UpdateQueueOutput, SdkError<UpdateQueueError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<UpdateQueueOutput, UpdateQueueError, Self>
pub fn customize( self, ) -> CustomizableOperation<UpdateQueueOutput, UpdateQueueError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn concurrent_jobs(self, input: i32) -> Self
pub fn concurrent_jobs(self, input: i32) -> Self
Specify the maximum number of jobs your queue can process concurrently. For on-demand queues, the value you enter is constrained by your service quotas for Maximum concurrent jobs, per on-demand queue and Maximum concurrent jobs, per account. For reserved queues, update your reservation plan instead in order to increase your yearly commitment.
Sourcepub fn set_concurrent_jobs(self, input: Option<i32>) -> Self
pub fn set_concurrent_jobs(self, input: Option<i32>) -> Self
Specify the maximum number of jobs your queue can process concurrently. For on-demand queues, the value you enter is constrained by your service quotas for Maximum concurrent jobs, per on-demand queue and Maximum concurrent jobs, per account. For reserved queues, update your reservation plan instead in order to increase your yearly commitment.
Sourcepub fn get_concurrent_jobs(&self) -> &Option<i32>
pub fn get_concurrent_jobs(&self) -> &Option<i32>
Specify the maximum number of jobs your queue can process concurrently. For on-demand queues, the value you enter is constrained by your service quotas for Maximum concurrent jobs, per on-demand queue and Maximum concurrent jobs, per account. For reserved queues, update your reservation plan instead in order to increase your yearly commitment.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The new description for the queue, if you are changing it.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The new description for the queue, if you are changing it.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The new description for the queue, if you are changing it.
Sourcepub fn maximum_concurrent_feeds(self, input: i32) -> Self
pub fn maximum_concurrent_feeds(self, input: i32) -> Self
Specify the maximum number of Elemental Inference feeds MediaConvert can process concurrently.
Sourcepub fn set_maximum_concurrent_feeds(self, input: Option<i32>) -> Self
pub fn set_maximum_concurrent_feeds(self, input: Option<i32>) -> Self
Specify the maximum number of Elemental Inference feeds MediaConvert can process concurrently.
Sourcepub fn get_maximum_concurrent_feeds(&self) -> &Option<i32>
pub fn get_maximum_concurrent_feeds(&self) -> &Option<i32>
Specify the maximum number of Elemental Inference feeds MediaConvert can process concurrently.
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the queue that you are modifying.
Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
The name of the queue that you are modifying.
Sourcepub fn reservation_plan_settings(self, input: ReservationPlanSettings) -> Self
pub fn reservation_plan_settings(self, input: ReservationPlanSettings) -> Self
The new details of your pricing plan for your reserved queue. When you set up a new pricing plan to replace an expired one, you enter into another 12-month commitment. When you add capacity to your queue by increasing the number of RTS, you extend the term of your commitment to 12 months from when you add capacity. After you make these commitments, you can’t cancel them.
Sourcepub fn set_reservation_plan_settings(
self,
input: Option<ReservationPlanSettings>,
) -> Self
pub fn set_reservation_plan_settings( self, input: Option<ReservationPlanSettings>, ) -> Self
The new details of your pricing plan for your reserved queue. When you set up a new pricing plan to replace an expired one, you enter into another 12-month commitment. When you add capacity to your queue by increasing the number of RTS, you extend the term of your commitment to 12 months from when you add capacity. After you make these commitments, you can’t cancel them.
Sourcepub fn get_reservation_plan_settings(&self) -> &Option<ReservationPlanSettings>
pub fn get_reservation_plan_settings(&self) -> &Option<ReservationPlanSettings>
The new details of your pricing plan for your reserved queue. When you set up a new pricing plan to replace an expired one, you enter into another 12-month commitment. When you add capacity to your queue by increasing the number of RTS, you extend the term of your commitment to 12 months from when you add capacity. After you make these commitments, you can’t cancel them.
Sourcepub fn status(self, input: QueueStatus) -> Self
pub fn status(self, input: QueueStatus) -> Self
Pause or activate a queue by changing its status between ACTIVE and PAUSED. If you pause a queue, jobs in that queue won’t begin. Jobs that are running when you pause the queue continue to run until they finish or result in an error.
Sourcepub fn set_status(self, input: Option<QueueStatus>) -> Self
pub fn set_status(self, input: Option<QueueStatus>) -> Self
Pause or activate a queue by changing its status between ACTIVE and PAUSED. If you pause a queue, jobs in that queue won’t begin. Jobs that are running when you pause the queue continue to run until they finish or result in an error.
Sourcepub fn get_status(&self) -> &Option<QueueStatus>
pub fn get_status(&self) -> &Option<QueueStatus>
Pause or activate a queue by changing its status between ACTIVE and PAUSED. If you pause a queue, jobs in that queue won’t begin. Jobs that are running when you pause the queue continue to run until they finish or result in an error.