#[non_exhaustive]pub enum XavcFramerateConversionAlgorithm {
DuplicateDrop,
Frameformer,
Interpolate,
MaintainFrameCount,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against XavcFramerateConversionAlgorithm, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let xavcframerateconversionalgorithm = unimplemented!();
match xavcframerateconversionalgorithm {
XavcFramerateConversionAlgorithm::DuplicateDrop => { /* ... */ },
XavcFramerateConversionAlgorithm::Frameformer => { /* ... */ },
XavcFramerateConversionAlgorithm::Interpolate => { /* ... */ },
XavcFramerateConversionAlgorithm::MaintainFrameCount => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when xavcframerateconversionalgorithm represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant XavcFramerateConversionAlgorithm::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
XavcFramerateConversionAlgorithm::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant XavcFramerateConversionAlgorithm::NewFeature is defined.
Specifically, when xavcframerateconversionalgorithm represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on XavcFramerateConversionAlgorithm::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
Choose the method that you want MediaConvert to use when increasing or decreasing your video’s frame rate. For numerically simple conversions, such as 60 fps to 30 fps: We recommend that you keep the default value, Drop duplicate. For numerically complex conversions, to avoid stutter: Choose Interpolate. This results in a smooth picture, but might introduce undesirable video artifacts. For complex frame rate conversions, especially if your source video has already been converted from its original cadence: Choose FrameFormer to do motion-compensated interpolation. FrameFormer uses the best conversion method frame by frame. Note that using FrameFormer increases the transcoding time and incurs a significant add-on cost. When you choose FrameFormer, your input video resolution must be at least 128x96. To create an output with the same number of frames as your input: Choose Maintain frame count. When you do, MediaConvert will not drop, interpolate, add, or otherwise change the frame count from your input to your output. Note that since the frame count is maintained, the duration of your output will become shorter at higher frame rates and longer at lower frame rates.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
DuplicateDrop
Frameformer
Interpolate
MaintainFrameCount
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl XavcFramerateConversionAlgorithm
impl XavcFramerateConversionAlgorithm
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.