#[non_exhaustive]pub struct EmbeddedDestinationSettings {
pub destination608_channel_number: Option<i32>,
pub destination708_service_number: Option<i32>,
}Expand description
Settings related to CEA/EIA-608 and CEA/EIA-708 (also called embedded or ancillary) captions. Set up embedded captions in the same output as your video. For more information, see https://docs.aws.amazon.com/mediaconvert/latest/ug/embedded-output-captions.html.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.destination608_channel_number: Option<i32>Ignore this setting unless your input captions are SCC format and your output captions are embedded in the video stream. Specify a CC number for each captions channel in this output. If you have two channels, choose CC numbers that aren’t in the same field. For example, choose 1 and 3. For more information, see https://docs.aws.amazon.com/console/mediaconvert/dual-scc-to-embedded.
destination708_service_number: Option<i32>Ignore this setting unless your input captions are SCC format and you want both 608 and 708 captions embedded in your output stream. Optionally, specify the 708 service number for each output captions channel. Choose a different number for each channel. To use this setting, also set Force 608 to 708 upconvert to Upconvert in your input captions selector settings. If you choose to upconvert but don’t specify a 708 service number, MediaConvert uses the number that you specify for CC channel number for the 708 service number. For more information, see https://docs.aws.amazon.com/console/mediaconvert/dual-scc-to-embedded.
Implementations
Sourceimpl EmbeddedDestinationSettings
impl EmbeddedDestinationSettings
Sourcepub fn destination608_channel_number(&self) -> Option<i32>
pub fn destination608_channel_number(&self) -> Option<i32>
Ignore this setting unless your input captions are SCC format and your output captions are embedded in the video stream. Specify a CC number for each captions channel in this output. If you have two channels, choose CC numbers that aren’t in the same field. For example, choose 1 and 3. For more information, see https://docs.aws.amazon.com/console/mediaconvert/dual-scc-to-embedded.
Sourcepub fn destination708_service_number(&self) -> Option<i32>
pub fn destination708_service_number(&self) -> Option<i32>
Ignore this setting unless your input captions are SCC format and you want both 608 and 708 captions embedded in your output stream. Optionally, specify the 708 service number for each output captions channel. Choose a different number for each channel. To use this setting, also set Force 608 to 708 upconvert to Upconvert in your input captions selector settings. If you choose to upconvert but don’t specify a 708 service number, MediaConvert uses the number that you specify for CC channel number for the 708 service number. For more information, see https://docs.aws.amazon.com/console/mediaconvert/dual-scc-to-embedded.
Sourceimpl EmbeddedDestinationSettings
impl EmbeddedDestinationSettings
Sourcepub fn builder() -> EmbeddedDestinationSettingsBuilder
pub fn builder() -> EmbeddedDestinationSettingsBuilder
Creates a new builder-style object to manufacture EmbeddedDestinationSettings.