#[non_exhaustive]pub struct FrameCaptureSettings {
pub framerate_denominator: Option<i32>,
pub framerate_numerator: Option<i32>,
pub max_captures: Option<i32>,
pub quality: Option<i32>,
}Expand description
Required when you set Codec to the value FRAME_CAPTURE.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.framerate_denominator: Option<i32>Frame capture will encode the first frame of the output stream, then one frame every framerateDenominator/framerateNumerator seconds. For example, settings of framerateNumerator = 1 and framerateDenominator = 3 (a rate of 1/3 frame per second) will capture the first frame, then 1 frame every 3s. Files will be named as filename.n.jpg where n is the 0-based sequence number of each Capture.
framerate_numerator: Option<i32>Frame capture will encode the first frame of the output stream, then one frame every framerateDenominator/framerateNumerator seconds. For example, settings of framerateNumerator = 1 and framerateDenominator = 3 (a rate of 1/3 frame per second) will capture the first frame, then 1 frame every 3s. Files will be named as filename.NNNNNNN.jpg where N is the 0-based frame sequence number zero padded to 7 decimal places.
max_captures: Option<i32>Maximum number of captures (encoded jpg output files).
quality: Option<i32>JPEG Quality - a higher value equals higher quality.
Implementations
Sourceimpl FrameCaptureSettings
impl FrameCaptureSettings
Sourcepub fn framerate_denominator(&self) -> Option<i32>
pub fn framerate_denominator(&self) -> Option<i32>
Frame capture will encode the first frame of the output stream, then one frame every framerateDenominator/framerateNumerator seconds. For example, settings of framerateNumerator = 1 and framerateDenominator = 3 (a rate of 1/3 frame per second) will capture the first frame, then 1 frame every 3s. Files will be named as filename.n.jpg where n is the 0-based sequence number of each Capture.
Sourcepub fn framerate_numerator(&self) -> Option<i32>
pub fn framerate_numerator(&self) -> Option<i32>
Frame capture will encode the first frame of the output stream, then one frame every framerateDenominator/framerateNumerator seconds. For example, settings of framerateNumerator = 1 and framerateDenominator = 3 (a rate of 1/3 frame per second) will capture the first frame, then 1 frame every 3s. Files will be named as filename.NNNNNNN.jpg where N is the 0-based frame sequence number zero padded to 7 decimal places.
Sourcepub fn max_captures(&self) -> Option<i32>
pub fn max_captures(&self) -> Option<i32>
Maximum number of captures (encoded jpg output files).
Sourceimpl FrameCaptureSettings
impl FrameCaptureSettings
Sourcepub fn builder() -> FrameCaptureSettingsBuilder
pub fn builder() -> FrameCaptureSettingsBuilder
Creates a new builder-style object to manufacture FrameCaptureSettings.