#[non_exhaustive]pub struct InputVideoGenerator {
pub channels: Option<i32>,
pub duration: Option<i32>,
pub framerate_denominator: Option<i32>,
pub framerate_numerator: Option<i32>,
pub height: Option<i32>,
pub image_input: Option<String>,
pub sample_rate: Option<i32>,
pub width: Option<i32>,
}Expand description
When you include Video generator, MediaConvert creates a video input with black frames. Use this setting if you do not have a video input or if you want to add black video frames before, or after, other inputs. You can specify Video generator, or you can specify an Input file, but you cannot specify both. For more information, see https://docs.aws.amazon.com/mediaconvert/latest/ug/video-generator.html
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channels: Option<i32>Specify the number of audio channels to include in your video generator input. MediaConvert creates these audio channels as silent audio within a single audio track. Enter an integer from 1 to 32.
duration: Option<i32>Specify the duration, in milliseconds, for your video generator input. Enter an integer from 1 to 86400000.
framerate_denominator: Option<i32>Specify the denominator of the fraction that represents the frame rate for your video generator input. When you do, you must also specify a value for Frame rate numerator. MediaConvert uses a default frame rate of 29.97 when you leave Frame rate numerator and Frame rate denominator blank.
framerate_numerator: Option<i32>Specify the numerator of the fraction that represents the frame rate for your video generator input. When you do, you must also specify a value for Frame rate denominator. MediaConvert uses a default frame rate of 29.97 when you leave Frame rate numerator and Frame rate denominator blank.
height: Option<i32>Specify the height, in pixels, for your video generator input. This is useful for positioning when you include one or more video overlays for this input. To use the default resolution 540x360: Leave both width and height blank. To specify a height: Enter an even integer from 32 to 8192. When you do, you must also specify a value for width.
image_input: Option<String>Specify the HTTP, HTTPS, or Amazon S3 location of the image that you want to overlay on the video. Use a PNG or TGA file.
sample_rate: Option<i32>Specify the audio sample rate, in Hz, for the silent audio in your video generator input. Enter an integer from 32000 to 48000.
width: Option<i32>Specify the width, in pixels, for your video generator input. This is useful for positioning when you include one or more video overlays for this input. To use the default resolution 540x360: Leave both width and height blank. To specify a width: Enter an even integer from 32 to 8192. When you do, you must also specify a value for height.
Implementations
Sourceimpl InputVideoGenerator
impl InputVideoGenerator
Sourcepub fn channels(&self) -> Option<i32>
pub fn channels(&self) -> Option<i32>
Specify the number of audio channels to include in your video generator input. MediaConvert creates these audio channels as silent audio within a single audio track. Enter an integer from 1 to 32.
Sourcepub fn duration(&self) -> Option<i32>
pub fn duration(&self) -> Option<i32>
Specify the duration, in milliseconds, for your video generator input. Enter an integer from 1 to 86400000.
Sourcepub fn framerate_denominator(&self) -> Option<i32>
pub fn framerate_denominator(&self) -> Option<i32>
Specify the denominator of the fraction that represents the frame rate for your video generator input. When you do, you must also specify a value for Frame rate numerator. MediaConvert uses a default frame rate of 29.97 when you leave Frame rate numerator and Frame rate denominator blank.
Sourcepub fn framerate_numerator(&self) -> Option<i32>
pub fn framerate_numerator(&self) -> Option<i32>
Specify the numerator of the fraction that represents the frame rate for your video generator input. When you do, you must also specify a value for Frame rate denominator. MediaConvert uses a default frame rate of 29.97 when you leave Frame rate numerator and Frame rate denominator blank.
Sourcepub fn height(&self) -> Option<i32>
pub fn height(&self) -> Option<i32>
Specify the height, in pixels, for your video generator input. This is useful for positioning when you include one or more video overlays for this input. To use the default resolution 540x360: Leave both width and height blank. To specify a height: Enter an even integer from 32 to 8192. When you do, you must also specify a value for width.
Sourcepub fn image_input(&self) -> Option<&str>
pub fn image_input(&self) -> Option<&str>
Specify the HTTP, HTTPS, or Amazon S3 location of the image that you want to overlay on the video. Use a PNG or TGA file.
Sourcepub fn sample_rate(&self) -> Option<i32>
pub fn sample_rate(&self) -> Option<i32>
Specify the audio sample rate, in Hz, for the silent audio in your video generator input. Enter an integer from 32000 to 48000.
Sourcepub fn width(&self) -> Option<i32>
pub fn width(&self) -> Option<i32>
Specify the width, in pixels, for your video generator input. This is useful for positioning when you include one or more video overlays for this input. To use the default resolution 540x360: Leave both width and height blank. To specify a width: Enter an even integer from 32 to 8192. When you do, you must also specify a value for height.
Sourceimpl InputVideoGenerator
impl InputVideoGenerator
Sourcepub fn builder() -> InputVideoGeneratorBuilder
pub fn builder() -> InputVideoGeneratorBuilder
Creates a new builder-style object to manufacture InputVideoGenerator.