#[non_exhaustive]pub struct Output {
pub audio_descriptions: Option<Vec<AudioDescription>>,
pub caption_descriptions: Option<Vec<CaptionDescription>>,
pub container_settings: Option<ContainerSettings>,
pub extension: Option<String>,
pub name_modifier: Option<String>,
pub output_settings: Option<OutputSettings>,
pub preset: Option<String>,
pub video_description: Option<VideoDescription>,
}Expand description
Each output in your job is a collection of settings that describes how you want MediaConvert to encode a single output file or stream. For more information, see https://docs.aws.amazon.com/mediaconvert/latest/ug/create-outputs.html.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.audio_descriptions: Option<Vec<AudioDescription>>Contains groups of audio encoding settings organized by audio codec. Include one instance of per output. Can contain multiple groups of encoding settings.
caption_descriptions: Option<Vec<CaptionDescription>>Contains groups of captions settings. For each output that has captions, include one instance of CaptionDescriptions. Can contain multiple groups of captions settings.
container_settings: Option<ContainerSettings>Container specific settings.
extension: Option<String>Use Extension to specify the file extension for outputs in File output groups. If you do not specify a value, the service will use default extensions by container type as follows * MPEG-2 transport stream, m2ts * Quicktime, mov * MXF container, mxf * MPEG-4 container, mp4 * WebM container, webm * Animated GIF container, gif * No Container, the service will use codec extensions (e.g. AAC, H265, H265, AC3)
name_modifier: Option<String>Use Name modifier to have the service add a string to the end of each output filename. You specify the base filename as part of your destination URI. When you create multiple outputs in the same output group, Name modifier is required. Name modifier also accepts format identifiers. For DASH ISO outputs, if you use the format identifiers $Number$ or $Time$ in one output, you must use them in the same way in all outputs of the output group.
output_settings: Option<OutputSettings>Specific settings for this type of output.
preset: Option<String>Use Preset to specify a preset for your transcoding settings. Provide the system or custom preset name. You can specify either Preset or Container settings, but not both.
video_description: Option<VideoDescription>VideoDescription contains a group of video encoding settings. The specific video settings depend on the video codec that you choose for the property codec. Include one instance of VideoDescription per output.
Implementations
Sourceimpl Output
impl Output
Sourcepub fn audio_descriptions(&self) -> &[AudioDescription]
pub fn audio_descriptions(&self) -> &[AudioDescription]
Contains groups of audio encoding settings organized by audio codec. Include one instance of per output. Can contain multiple groups of encoding settings.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .audio_descriptions.is_none().
Sourcepub fn caption_descriptions(&self) -> &[CaptionDescription]
pub fn caption_descriptions(&self) -> &[CaptionDescription]
Contains groups of captions settings. For each output that has captions, include one instance of CaptionDescriptions. Can contain multiple groups of captions settings.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .caption_descriptions.is_none().
Sourcepub fn container_settings(&self) -> Option<&ContainerSettings>
pub fn container_settings(&self) -> Option<&ContainerSettings>
Container specific settings.
Sourcepub fn extension(&self) -> Option<&str>
pub fn extension(&self) -> Option<&str>
Use Extension to specify the file extension for outputs in File output groups. If you do not specify a value, the service will use default extensions by container type as follows * MPEG-2 transport stream, m2ts * Quicktime, mov * MXF container, mxf * MPEG-4 container, mp4 * WebM container, webm * Animated GIF container, gif * No Container, the service will use codec extensions (e.g. AAC, H265, H265, AC3)
Sourcepub fn name_modifier(&self) -> Option<&str>
pub fn name_modifier(&self) -> Option<&str>
Use Name modifier to have the service add a string to the end of each output filename. You specify the base filename as part of your destination URI. When you create multiple outputs in the same output group, Name modifier is required. Name modifier also accepts format identifiers. For DASH ISO outputs, if you use the format identifiers $Number$ or $Time$ in one output, you must use them in the same way in all outputs of the output group.
Sourcepub fn output_settings(&self) -> Option<&OutputSettings>
pub fn output_settings(&self) -> Option<&OutputSettings>
Specific settings for this type of output.
Sourcepub fn preset(&self) -> Option<&str>
pub fn preset(&self) -> Option<&str>
Use Preset to specify a preset for your transcoding settings. Provide the system or custom preset name. You can specify either Preset or Container settings, but not both.
Sourcepub fn video_description(&self) -> Option<&VideoDescription>
pub fn video_description(&self) -> Option<&VideoDescription>
VideoDescription contains a group of video encoding settings. The specific video settings depend on the video codec that you choose for the property codec. Include one instance of VideoDescription per output.