#[non_exhaustive]pub struct Queue {Show 14 fields
pub arn: Option<String>,
pub concurrent_jobs: Option<i32>,
pub created_at: Option<DateTime>,
pub description: Option<String>,
pub last_updated: Option<DateTime>,
pub maximum_concurrent_feeds: Option<i32>,
pub name: Option<String>,
pub pricing_plan: Option<PricingPlan>,
pub progressing_jobs_count: Option<i32>,
pub reservation_plan: Option<ReservationPlan>,
pub service_overrides: Option<Vec<ServiceOverride>>,
pub status: Option<QueueStatus>,
pub submitted_jobs_count: Option<i32>,
pub type: Option<Type>,
}Expand description
You can use queues to manage the resources that are available to your AWS account for running multiple transcoding jobs at the same time. If you don’t specify a queue, the service sends all jobs through the default queue. For more information, see https://docs.aws.amazon.com/mediaconvert/latest/ug/working-with-queues.html.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.arn: Option<String>An identifier for this resource that is unique within all of AWS.
concurrent_jobs: Option<i32>The maximum number of jobs your queue can process concurrently.
created_at: Option<DateTime>The timestamp in epoch seconds for when you created the queue.
description: Option<String>An optional description that you create for each queue.
last_updated: Option<DateTime>The timestamp in epoch seconds for when you most recently updated the queue.
maximum_concurrent_feeds: Option<i32>Specify the maximum number of Elemental Inference feeds MediaConvert can process concurrently.
name: Option<String>A name that you create for each queue. Each name must be unique within your account.
pricing_plan: Option<PricingPlan>Specifies whether the pricing plan for the queue is on-demand or reserved. For on-demand, you pay per minute, billed in increments of .01 minute. For reserved, you pay for the transcoding capacity of the entire queue, regardless of how much or how little you use it. Reserved pricing requires a 12-month commitment.
progressing_jobs_count: Option<i32>The estimated number of jobs with a PROGRESSING status.
reservation_plan: Option<ReservationPlan>Details about the pricing plan for your reserved queue. Required for reserved queues and not applicable to on-demand queues.
service_overrides: Option<Vec<ServiceOverride>>A list of any service overrides applied by MediaConvert to the settings that you have configured. If you see any overrides, we recommend that you contact AWS Support.
status: Option<QueueStatus>Queues can be ACTIVE or PAUSED. If you pause a queue, the service won’t begin processing jobs in that queue. Jobs that are running when you pause the queue continue to run until they finish or result in an error.
submitted_jobs_count: Option<i32>The estimated number of jobs with a SUBMITTED status.
type: Option<Type>Specifies whether this on-demand queue is system or custom. System queues are built in. You can’t modify or delete system queues. You can create and modify custom queues.
Implementations
Sourceimpl Queue
impl Queue
Sourcepub fn arn(&self) -> Option<&str>
pub fn arn(&self) -> Option<&str>
An identifier for this resource that is unique within all of AWS.
Sourcepub fn concurrent_jobs(&self) -> Option<i32>
pub fn concurrent_jobs(&self) -> Option<i32>
The maximum number of jobs your queue can process concurrently.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The timestamp in epoch seconds for when you created the queue.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
An optional description that you create for each queue.
Sourcepub fn last_updated(&self) -> Option<&DateTime>
pub fn last_updated(&self) -> Option<&DateTime>
The timestamp in epoch seconds for when you most recently updated the queue.
Sourcepub fn maximum_concurrent_feeds(&self) -> Option<i32>
pub fn maximum_concurrent_feeds(&self) -> Option<i32>
Specify the maximum number of Elemental Inference feeds MediaConvert can process concurrently.
Sourcepub fn name(&self) -> Option<&str>
pub fn name(&self) -> Option<&str>
A name that you create for each queue. Each name must be unique within your account.
Sourcepub fn pricing_plan(&self) -> Option<&PricingPlan>
pub fn pricing_plan(&self) -> Option<&PricingPlan>
Specifies whether the pricing plan for the queue is on-demand or reserved. For on-demand, you pay per minute, billed in increments of .01 minute. For reserved, you pay for the transcoding capacity of the entire queue, regardless of how much or how little you use it. Reserved pricing requires a 12-month commitment.
Sourcepub fn progressing_jobs_count(&self) -> Option<i32>
pub fn progressing_jobs_count(&self) -> Option<i32>
The estimated number of jobs with a PROGRESSING status.
Sourcepub fn reservation_plan(&self) -> Option<&ReservationPlan>
pub fn reservation_plan(&self) -> Option<&ReservationPlan>
Details about the pricing plan for your reserved queue. Required for reserved queues and not applicable to on-demand queues.
Sourcepub fn service_overrides(&self) -> &[ServiceOverride]
pub fn service_overrides(&self) -> &[ServiceOverride]
A list of any service overrides applied by MediaConvert to the settings that you have configured. If you see any overrides, we recommend that you contact AWS Support.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .service_overrides.is_none().
Sourcepub fn status(&self) -> Option<&QueueStatus>
pub fn status(&self) -> Option<&QueueStatus>
Queues can be ACTIVE or PAUSED. If you pause a queue, the service won’t begin processing jobs in that queue. Jobs that are running when you pause the queue continue to run until they finish or result in an error.
Sourcepub fn submitted_jobs_count(&self) -> Option<i32>
pub fn submitted_jobs_count(&self) -> Option<i32>
The estimated number of jobs with a SUBMITTED status.