#[non_exhaustive]pub struct VideoCodecSettings {Show 15 fields
pub av1_settings: Option<Av1Settings>,
pub avc_intra_settings: Option<AvcIntraSettings>,
pub codec: Option<VideoCodec>,
pub frame_capture_settings: Option<FrameCaptureSettings>,
pub gif_settings: Option<GifSettings>,
pub h264_settings: Option<H264Settings>,
pub h265_settings: Option<H265Settings>,
pub mpeg2_settings: Option<Mpeg2Settings>,
pub passthrough_settings: Option<PassthroughSettings>,
pub prores_settings: Option<ProresSettings>,
pub uncompressed_settings: Option<UncompressedSettings>,
pub vc3_settings: Option<Vc3Settings>,
pub vp8_settings: Option<Vp8Settings>,
pub vp9_settings: Option<Vp9Settings>,
pub xavc_settings: Option<XavcSettings>,
}Expand description
Video codec settings contains the group of settings related to video encoding. The settings in this group vary depending on the value that you choose for Video codec. For each codec enum that you choose, define the corresponding settings object. The following lists the codec enum, settings object pairs. * AV1, Av1Settings * AVC_INTRA, AvcIntraSettings * FRAME_CAPTURE, FrameCaptureSettings * GIF, GifSettings * H_264, H264Settings * H_265, H265Settings * MPEG2, Mpeg2Settings * PRORES, ProresSettings * UNCOMPRESSED, UncompressedSettings * VC3, Vc3Settings * VP8, Vp8Settings * VP9, Vp9Settings * XAVC, XavcSettings
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.av1_settings: Option<Av1Settings>Required when you set Codec, under VideoDescription>CodecSettings to the value AV1.
avc_intra_settings: Option<AvcIntraSettings>Required when you choose AVC-Intra for your output video codec. For more information about the AVC-Intra settings, see the relevant specification. For detailed information about SD and HD in AVC-Intra, see https://ieeexplore.ieee.org/document/7290936. For information about 4K/2K in AVC-Intra, see https://pro-av.panasonic.net/en/avc-ultra/AVC-ULTRAoverview.pdf.
codec: Option<VideoCodec>Specifies the video codec. This must be equal to one of the enum values defined by the object VideoCodec. To passthrough the video stream of your input without any video encoding: Choose Passthrough. More information about passthrough codec support and job settings requirements, see: https://docs.aws.amazon.com/mediaconvert/latest/ug/video-passthrough-feature-restrictions.html
frame_capture_settings: Option<FrameCaptureSettings>Required when you set Codec to the value FRAME_CAPTURE.
gif_settings: Option<GifSettings>Required when you set (Codec) under (VideoDescription)>(CodecSettings) to the value GIF
h264_settings: Option<H264Settings>Required when you set Codec to the value H_264.
h265_settings: Option<H265Settings>Settings for H265 codec
mpeg2_settings: Option<Mpeg2Settings>Required when you set Codec to the value MPEG2.
passthrough_settings: Option<PassthroughSettings>Optional settings when you set Codec to the value Passthrough.
prores_settings: Option<ProresSettings>Required when you set Codec to the value PRORES.
uncompressed_settings: Option<UncompressedSettings>Required when you set Codec, under VideoDescription>CodecSettings to the value UNCOMPRESSED.
vc3_settings: Option<Vc3Settings>Required when you set Codec to the value VC3
vp8_settings: Option<Vp8Settings>Required when you set Codec to the value VP8.
vp9_settings: Option<Vp9Settings>Required when you set Codec to the value VP9.
xavc_settings: Option<XavcSettings>Required when you set Codec to the value XAVC.
Implementations
Sourceimpl VideoCodecSettings
impl VideoCodecSettings
Sourcepub fn av1_settings(&self) -> Option<&Av1Settings>
pub fn av1_settings(&self) -> Option<&Av1Settings>
Required when you set Codec, under VideoDescription>CodecSettings to the value AV1.
Sourcepub fn avc_intra_settings(&self) -> Option<&AvcIntraSettings>
pub fn avc_intra_settings(&self) -> Option<&AvcIntraSettings>
Required when you choose AVC-Intra for your output video codec. For more information about the AVC-Intra settings, see the relevant specification. For detailed information about SD and HD in AVC-Intra, see https://ieeexplore.ieee.org/document/7290936. For information about 4K/2K in AVC-Intra, see https://pro-av.panasonic.net/en/avc-ultra/AVC-ULTRAoverview.pdf.
Sourcepub fn codec(&self) -> Option<&VideoCodec>
pub fn codec(&self) -> Option<&VideoCodec>
Specifies the video codec. This must be equal to one of the enum values defined by the object VideoCodec. To passthrough the video stream of your input without any video encoding: Choose Passthrough. More information about passthrough codec support and job settings requirements, see: https://docs.aws.amazon.com/mediaconvert/latest/ug/video-passthrough-feature-restrictions.html
Sourcepub fn frame_capture_settings(&self) -> Option<&FrameCaptureSettings>
pub fn frame_capture_settings(&self) -> Option<&FrameCaptureSettings>
Required when you set Codec to the value FRAME_CAPTURE.
Sourcepub fn gif_settings(&self) -> Option<&GifSettings>
pub fn gif_settings(&self) -> Option<&GifSettings>
Required when you set (Codec) under (VideoDescription)>(CodecSettings) to the value GIF
Sourcepub fn h264_settings(&self) -> Option<&H264Settings>
pub fn h264_settings(&self) -> Option<&H264Settings>
Required when you set Codec to the value H_264.
Sourcepub fn h265_settings(&self) -> Option<&H265Settings>
pub fn h265_settings(&self) -> Option<&H265Settings>
Settings for H265 codec
Sourcepub fn mpeg2_settings(&self) -> Option<&Mpeg2Settings>
pub fn mpeg2_settings(&self) -> Option<&Mpeg2Settings>
Required when you set Codec to the value MPEG2.
Sourcepub fn passthrough_settings(&self) -> Option<&PassthroughSettings>
pub fn passthrough_settings(&self) -> Option<&PassthroughSettings>
Optional settings when you set Codec to the value Passthrough.
Sourcepub fn prores_settings(&self) -> Option<&ProresSettings>
pub fn prores_settings(&self) -> Option<&ProresSettings>
Required when you set Codec to the value PRORES.
Sourcepub fn uncompressed_settings(&self) -> Option<&UncompressedSettings>
pub fn uncompressed_settings(&self) -> Option<&UncompressedSettings>
Required when you set Codec, under VideoDescription>CodecSettings to the value UNCOMPRESSED.
Sourcepub fn vc3_settings(&self) -> Option<&Vc3Settings>
pub fn vc3_settings(&self) -> Option<&Vc3Settings>
Required when you set Codec to the value VC3
Sourcepub fn vp8_settings(&self) -> Option<&Vp8Settings>
pub fn vp8_settings(&self) -> Option<&Vp8Settings>
Required when you set Codec to the value VP8.
Sourcepub fn vp9_settings(&self) -> Option<&Vp9Settings>
pub fn vp9_settings(&self) -> Option<&Vp9Settings>
Required when you set Codec to the value VP9.
Sourcepub fn xavc_settings(&self) -> Option<&XavcSettings>
pub fn xavc_settings(&self) -> Option<&XavcSettings>
Required when you set Codec to the value XAVC.
Sourceimpl VideoCodecSettings
impl VideoCodecSettings
Sourcepub fn builder() -> VideoCodecSettingsBuilder
pub fn builder() -> VideoCodecSettingsBuilder
Creates a new builder-style object to manufacture VideoCodecSettings.